@@ -971,7 +971,7 @@ namespace KviLocale
 			if(findCatalogue(szBuffer,"kvirc",localeDir))
 			{
 				g_pMainCatalogue->load(szBuffer);
-				g_pTranslator = new KviTranslator(TQT_TQOBJECT(app),"kvirc_translator");
+				g_pTranslator = new KviTranslator(app,"kvirc_translator");
 				app->installTranslator(g_pTranslator);
 			} else {
 				KviStr szTmp = g_szLang;
@@ -1065,13 +1065,13 @@ KviTranslator::~KviTranslator()
 
 TQString KviTranslator::find(const char *context,const char * message) const
 {
-	// we ignore contexts for qt translations
+	// we ignore contexts for tqt translations
 	return g_pMainCatalogue->translateToTQString(message);
 }
 
 TQTranslatorMessage KviTranslator::findMessage(const char * context,const char * sourceText,const char * comment) const
 {
-	// we ignore contexts for qt translations
+	// we ignore contexts for tqt translations
 	return TQTranslatorMessage(context,sourceText,comment,g_pMainCatalogue->translateToTQString(sourceText));
 }
 
