@@ -337,7 +337,7 @@ class KVILIB_API KviThreadManager : public TQObject
 {
 	friend class KviApp;
 	friend class KviThread;
-	Q_OBJECT
+	TQ_OBJECT
   
 protected:
 	// These should be private...but we don't want anyone to complain
