@@ -27,54 +27,6 @@
 
 #include "kvi_tal_filedialog.h"
 
-#ifdef COMPILE_USE_QT4
-
-	#include <tqdir.h>
-
-	KviTalFileDialog::KviTalFileDialog(const TQString &dirName,const TQString &filter,TQWidget *parent,const char *name,bool modal)
-	: TQFileDialog(parent,"",dirName,filter)
-	{
-		setModal(modal);
-	}
-
-	KviTalFileDialog::~KviTalFileDialog()
-	{
-	}
-
-	void KviTalFileDialog::setFileMode(FileMode m)
-	{
-		switch(m)
-		{
-			case AnyFile:
-				TQFileDialog::setFileMode(TQFileDialog::AnyFile);
-			break;
-			case ExistingFile:
-				TQFileDialog::setFileMode(TQFileDialog::ExistingFile);
-			break;
-			case ExistingFiles:
-				TQFileDialog::setFileMode(TQFileDialog::ExistingFiles);
-			break;
-			case Directory:
-				TQFileDialog::setFileMode(TQFileDialog::Directory);
-			break;
-			case DirectoryOnly:
-				TQFileDialog::setFileMode(TQFileDialog::DirectoryOnly);
-			break;
-			default:
-				TQFileDialog::setFileMode(TQFileDialog::AnyFile);
-			break;
-		}
-	}
-	
-	void KviTalFileDialog::setDirectory(const TQString &szDirectory)
-	{
-		TQFileDialog::setDirectory(szDirectory);
-	}
-
-
-	#include "kvi_tal_filedialog_qt4.moc"
-
-#else
 
 	#ifdef COMPILE_TDE_SUPPORT
 	
@@ -173,4 +125,3 @@
 		#include "kvi_tal_filedialog_qt.moc"
 	
 	#endif
-#endif
