@@ -27,10 +27,6 @@
 
 #include "kvi_settings.h"
 
-#ifdef COMPILE_USE_QT4
-	#include "kvi_tal_hbox_qt4.h"
-#else
 	#include "kvi_tal_hbox_qt3.h"
-#endif
 
 #endif // _KVI_TAL_HBOX_H_
