@@ -36,30 +36,11 @@
 
 #else
 
-	#ifdef COMPILE_USE_QT4
-		KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
-		: TQMainWindow(par,nam)
-		{
-		}
-
-		bool KviTalMainWindow::usesBigPixmaps()
-		{
-			return (iconSize().width() > 40);
-		}
-		
-		void KviTalMainWindow::setUsesBigPixmaps(bool b)
-		{
-			if(b)setIconSize(TQSize(48,48));
-			else setIconSize(TQSize(24,24));
-		}
-		#include "kvi_tal_mainwindow_qt4.moc"
-	#else
 		KviTalMainWindow::KviTalMainWindow(TQWidget * par,const char * nam)
 		: TQMainWindow(par,nam)
 		{
 		}
 		#include "kvi_tal_mainwindow_qt3.moc"
-	#endif
 
 #endif
 
