@@ -27,7 +27,7 @@
 
 class KVILIB_API KviTalMainWindow : public TDEMainWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTalMainWindow(TQWidget * par,const char * nam);
