@@ -31,7 +31,7 @@
 
 class KVILIB_API KviTalScrollView : public TQScrollView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTalScrollView(TQWidget * pParent)
