@@ -29,7 +29,7 @@
 
 class KVILIB_API KviTalToolBar : public TQToolBar
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTalToolBar(const TQString &label,TQMainWindow *w,TQT_TOOLBARDOCK_TYPE dock = TQT_DOCK_TOP,bool bNewLine = false,const char * nam = 0);
