@@ -25,9 +25,5 @@
 #define __KVILIB__
 #include "kvi_tal_widgetstack.h"
 
-#ifdef COMPILE_USE_QT4
-	#include "kvi_tal_widgetstack_qt4.moc"
-#else
 	#include "kvi_tal_widgetstack_qt3.moc"
-#endif
 
