@@ -191,9 +191,9 @@ KviTalWizard::KviTalWizard(TQWidget * pParent)
 	m_p->pCancelButton->setMinimumWidth(80);
 	TQObject::connect(
 			m_p->pCancelButton,
-			TQT_SIGNAL(clicked()),
+			TQ_SIGNAL(clicked()),
 			this,
-			TQT_SLOT(cancelButtonClicked())
+			TQ_SLOT(cancelButtonClicked())
 		);
 
 	TQWidget * pSpacer = new TQWidget(pButtonBox);
@@ -203,9 +203,9 @@ KviTalWizard::KviTalWizard(TQWidget * pParent)
 	m_p->pHelpButton->setMinimumWidth(80);
 	TQObject::connect(
 			m_p->pHelpButton,
-			TQT_SIGNAL(clicked()),
+			TQ_SIGNAL(clicked()),
 			this,
-			TQT_SLOT(helpButtonClicked())
+			TQ_SLOT(helpButtonClicked())
 		);
 
 	TQWidget * pLargeSpacer = new TQWidget(pButtonBox);
@@ -218,9 +218,9 @@ KviTalWizard::KviTalWizard(TQWidget * pParent)
 	m_p->pBackButton->setMinimumWidth(80);
 	TQObject::connect(
 			m_p->pBackButton,
-			TQT_SIGNAL(clicked()),
+			TQ_SIGNAL(clicked()),
 			this,
-			TQT_SLOT(backButtonClicked())
+			TQ_SLOT(backButtonClicked())
 		);
 
 	m_p->pNextSpacer = new TQWidget(pButtonBox);
@@ -232,9 +232,9 @@ KviTalWizard::KviTalWizard(TQWidget * pParent)
 	m_p->pNextButton->setMinimumWidth(80);
 	TQObject::connect(
 			m_p->pNextButton,
-			TQT_SIGNAL(clicked()),
+			TQ_SIGNAL(clicked()),
 			this,
-			TQT_SLOT(nextButtonClicked())
+			TQ_SLOT(nextButtonClicked())
 		);
 
 	m_p->pFinishSpacer = new TQWidget(pButtonBox);
@@ -244,9 +244,9 @@ KviTalWizard::KviTalWizard(TQWidget * pParent)
 	m_p->pFinishButton->setMinimumWidth(80);
 	TQObject::connect(
 			m_p->pFinishButton,
-			TQT_SIGNAL(clicked()),
+			TQ_SIGNAL(clicked()),
 			this,
-			TQT_SLOT(finishButtonClicked())
+			TQ_SLOT(finishButtonClicked())
 		);
 		
 	m_p->pLayout->setMargin(8);
