@@ -1821,7 +1821,7 @@ void KviApp::buildRecentChannels()
 	if(m_pRecentChannelsDict)
 		delete m_pRecentChannelsDict;
 	m_pRecentChannelsDict = new KviPointerHashTable<const char *,TQStringList>;
-	m_pRecentChannelsDict->setAutoDelete(TRUE);
+	m_pRecentChannelsDict->setAutoDelete(true);
 	TQString szChan,szNet;
 	for ( 
 		TQStringList::Iterator it = KVI_OPTION_STRINGLIST(KviOption_stringlistRecentChannels).begin();
