@@ -81,7 +81,7 @@ class KVIRC_API KviApp : public KviTalApplication
 	friend class KviFrame;
 	friend class KviWindow;
 	friend class KviSetupWizard; // this resides in a module!
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviApp(int &argc,char ** argv);
