@@ -78,9 +78,9 @@ void KviApp::getGlobalKvircDirectory(TQString &szData,KvircSubdir dir,const TQSt
 		break;
 		case HelpEN        : KviTQString::appendFormatted(szData,"help%sen",KVI_PATH_SEPARATOR);        break;
 		case HelpNoIntl    : szData.append("help");                                                    break;
-		case Log           : debug("WARNING Global log directory requested!");                         break;
-		case Incoming      : debug("WARNING Global incoming directory requested!");                    break;
-		case Trash         : debug("WARNING Global trash directory requested!");                       break;
+		case Log           : tqDebug("WARNING Global log directory requested!");                         break;
+		case Incoming      : tqDebug("WARNING Global incoming directory requested!");                    break;
+		case Trash         : tqDebug("WARNING Global trash directory requested!");                       break;
 		case Config        : szData.append("config");                                                  break;
 		case Audio         : szData.append("audio");                                                   break;
 		case Scripts       : szData.append("scripts");                                                 break;
@@ -91,7 +91,7 @@ void KviApp::getGlobalKvircDirectory(TQString &szData,KvircSubdir dir,const TQSt
 		case License       : szData.append("license");                                                 break;
 		case Filters       : szData.append("filters");                                                 break;
 		case Locale        : szData.append("locale");                                                  break;
-		case Tmp           : debug("WARNING Global tmp directory requested!");                         break;
+		case Tmp           : tqDebug("WARNING Global tmp directory requested!");                         break;
 		case Themes        : szData.append("themes");                                                  break;
 		case Classes       : szData.append("classes");                                                 break;
 		case SmallIcons    : szData.append("pics" KVI_PATH_SEPARATOR KVI_SMALLICONS_SUBDIRECTORY);      break;
@@ -438,7 +438,7 @@ bool KviApp::findImageInImageSearchPath(KviStr &szRetPath,const char * filename)
 		szRetPath = *it;
 		szRetPath.ensureLastCharIs(KVI_PATH_SEPARATOR_CHAR);
 		szRetPath.append(filename);
-		//debug("LOOK FOR %s",szRetPath.ptr());
+		//tqDebug("LOOK FOR %s",szRetPath.ptr());
 		if(KviFileUtils::fileExists(szRetPath.ptr()))return true;
 	}
 
@@ -454,7 +454,7 @@ bool KviApp::findImageInImageSearchPath(TQString &szRetPath,const char * filenam
 		szRetPath = *it;
 		KviTQString::ensureLastCharIs(szRetPath,KVI_PATH_SEPARATOR_CHAR);
 		szRetPath.append(filename);
-		//debug("LOOK FOR %s",szRetPath.ptr());
+		//tqDebug("LOOK FOR %s",szRetPath.ptr());
 		if(KviFileUtils::fileExists(szRetPath))return true;
 	}
 
@@ -513,7 +513,7 @@ bool KviApp::mapImageFile(TQString &szRetPath,const char * filename)
 		for(i=0;i<2;i++)
 		{
 			getGlobalKvircDirectory(szBuffer,pics_globalsubdirs[i],szRetPath);
-			//debug("CHECK %s",szBuffer.ptr());
+			//tqDebug("CHECK %s",szBuffer.ptr());
 			if(KviFileUtils::fileExists(szBuffer.ptr()))
 			{
 				TQFileInfo fi2(TQString::fromUtf8(szBuffer.ptr()));
@@ -711,7 +711,7 @@ bool KviApp::getReadOnlyConfigPath(TQString &buffer,const char *config_name,Kvir
 {
 	// Take a look in the local directory....
 	getLocalKvircDirectory(buffer,sbd,config_name);
-	//debug("%s %s %i |%s| %i",__FILE__,__FUNCTION__,__LINE__,buffer.ptr(),KviFileUtils::fileExists(buffer.ptr()));
+	//tqDebug("%s %s %i |%s| %i",__FILE__,__FUNCTION__,__LINE__,buffer.ptr(),KviFileUtils::fileExists(buffer.ptr()));
 	if(!KviFileUtils::fileExists(buffer))
 	{
 		// No saved config yet... check for defaults
