@@ -46,7 +46,7 @@ class KVIRC_API KviFileTransferManager : public TQObject
 	friend class KviApp;
 	friend class KviFileTransfer;
 	friend class KviFileTransferWindow;
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviFileTransferManager();
@@ -79,7 +79,7 @@ signals:
 
 class KVIRC_API KviFileTransfer : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviFileTransfer();
