@@ -85,7 +85,7 @@
 			int format;
 			unsigned long nItems,after;
 			unsigned char * data = 0;
-			if(XGetWindowProperty(kvi_ipc_get_xdisplay(),win,kvi_atom_ipc_sentinel_window,0,32,FALSE,XA_STRING,
+			if(XGetWindowProperty(kvi_ipc_get_xdisplay(),win,kvi_atom_ipc_sentinel_window,0,32,False,XA_STRING,
 				&type,&format,&nItems,&after,&data) == Success)
 			{
 				if((type == XA_STRING) && (format == 8))
@@ -238,7 +238,7 @@
 					unsigned long nItems,after;
 					unsigned char * data = 0;
 					KviStr szData;
-					if(XGetWindowProperty(kvi_ipc_get_xdisplay(),winId(),kvi_atom_ipc_remote_command,0,1024,FALSE,XA_STRING,
+					if(XGetWindowProperty(kvi_ipc_get_xdisplay(),winId(),kvi_atom_ipc_remote_command,0,1024,False,XA_STRING,
 						&type,&format,&nItems,&after,&data) == Success)
 					{
 						if((type == XA_STRING) && (format == 8) && (nItems > 0) && data)
