@@ -109,7 +109,7 @@ KviIrcConnection::~KviIrcConnection()
 	m_bIdentdAttached = false;
 	if(m_pLocalhostDns)
 	{
-		TQObject::disconnect(m_pLocalhostDns,TQT_SIGNAL(lookupDone(KviDns *)),0,0);
+		TQObject::disconnect(m_pLocalhostDns,TQ_SIGNAL(lookupDone(KviDns *)),0,0);
 		if(m_pLocalhostDns->isRunning())
 		{
 			g_pGarbageCollector->collect(m_pLocalhostDns);
@@ -186,7 +186,7 @@ void KviIrcConnection::setupTextCodec()
 	if(!m_pTarget->server()->encoding().isEmpty())
 	{
 		m_pTextCodec = KviLocale::codecForName(m_pTarget->server()->encoding().latin1());
-		if(!m_pTextCodec)debug("KviIrcConnection: can't find TQTextCodec for encoding %s",m_pTarget->server()->encoding().utf8().data());
+		if(!m_pTextCodec)tqDebug("KviIrcConnection: can't find TQTextCodec for encoding %s",m_pTarget->server()->encoding().utf8().data());
 	}
 	if(!m_pTextCodec)
 	{
@@ -194,7 +194,7 @@ void KviIrcConnection::setupTextCodec()
 		if(!m_pTarget->network()->encoding().isEmpty())
 		{
 			m_pTextCodec = KviLocale::codecForName(m_pTarget->network()->encoding().latin1());
-			if(!m_pTextCodec)debug("KviIrcConnection: can't find TQTextCodec for encoding %s",m_pTarget->network()->encoding().utf8().data());
+			if(!m_pTextCodec)tqDebug("KviIrcConnection: can't find TQTextCodec for encoding %s",m_pTarget->network()->encoding().utf8().data());
 		}
 	}
 	if(!m_pTextCodec)
@@ -600,7 +600,7 @@ void KviIrcConnection::delayedStartNotifyList()
 
 	if(m_pNotifyListTimer)delete m_pNotifyListTimer;
 	m_pNotifyListTimer = new TQTimer();
-	connect(m_pNotifyListTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(restartNotifyList()));
+	connect(m_pNotifyListTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(restartNotifyList()));
 	m_pNotifyListTimer->start(15000,true);
 
 	// This delay is large enough to fire after the MOTD has been sent,
@@ -805,7 +805,7 @@ void KviIrcConnection::userInfoReceived(const TQString &szUserName,const TQStrin
 			// look it up too
 			if(m_pLocalhostDns)delete m_pLocalhostDns; // it could be only another local host lookup
 			m_pLocalhostDns = new KviDns();
-			connect(m_pLocalhostDns,TQT_SIGNAL(lookupDone(KviDns *)),this,TQT_SLOT(hostNameLookupTerminated(KviDns *)));
+			connect(m_pLocalhostDns,TQ_SIGNAL(lookupDone(KviDns *)),this,TQ_SLOT(hostNameLookupTerminated(KviDns *)));
 
 			if(!m_pLocalhostDns->lookup(szHostName,KviDns::Any))
 			{
@@ -832,7 +832,7 @@ void KviIrcConnection::hostNameLookupTerminated(KviDns *pDns)
 	//
 	if(!m_pLocalhostDns)
 	{
-		debug("Something weird is happening: pDns != 0 but m_pLocalhostDns == 0 :/");
+		tqDebug("Something weird is happening: pDns != 0 but m_pLocalhostDns == 0 :/");
 		return;
 	}
 
