@@ -38,7 +38,7 @@ class TQTimer;
 class KVIRC_API KviIrcConnectionTargetResolver : public TQObject
 {
 	friend class KviIrcLink; // upper protocol in the stack
-	Q_OBJECT
+	TQ_OBJECT
   
 protected:
 	KviIrcConnectionTargetResolver(KviIrcConnection * pConnection);
