@@ -33,7 +33,7 @@ class KviKvsScript;
 
 class KVIRC_API KviKvsAction : public KviAction
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 protected:
 	KviKvsScript * m_pScript;
