@@ -355,7 +355,7 @@ namespace KviKvsCoreFunctions
 			It allows an alias to handle switches just like any other
 			KVIrc command. If a switch in the form -<letter> was
 			passed to the current alias then $sw(<letter>)
-			returns 1 (true). If a switch in the form -<letter>=<value>
+			returns true. If a switch in the form -<letter>=<value>
 			was passed to the current alias then <value> is returned.
 			If the switch was not present at all then this function
 			returns an empty string (that evaluates to false in an expression).
