@@ -1086,7 +1086,7 @@ namespace KviKvsCoreSimpleCommands
 
 		if(KVSCSC_pSwitches->find('q',"quit"))
 		{
-			TQTimer::singleShot(0,g_pApp,TQT_SLOT(quit()));
+			TQTimer::singleShot(0,g_pApp,TQ_SLOT(quit()));
 		} else {
 			KVSCSC_REQUIRE_CONNECTION
 			KVSCSC_pWindow->context()->terminateConnectionRequest(KVSCSC_pSwitches->find('f',"force"),szReason,KVSCSC_pSwitches->find('u',"unexpected"));
