@@ -58,7 +58,7 @@ void KviKvsTreeNodeOperation::contextDescription(TQString &szBuffer)
 
 void KviKvsTreeNodeOperation::dump(const char * prefix)
 {
-	debug("%s Operation",prefix);
+	tqDebug("%s Operation",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -88,7 +88,7 @@ void KviKvsTreeNodeOperationAssignment::contextDescription(TQString &szBuffer)
 
 void KviKvsTreeNodeOperationAssignment::dump(const char * prefix)
 {
-	debug("%s OperationAssignment",prefix);
+	tqDebug("%s OperationAssignment",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -133,7 +133,7 @@ void KviKvsTreeNodeOperationDecrement::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationDecrement::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationDecrement",prefix);
+	tqDebug("%s OperationDecrement",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -196,7 +196,7 @@ void KviKvsTreeNodeOperationIncrement::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationIncrement::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationIncrement",prefix);
+	tqDebug("%s OperationIncrement",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -262,7 +262,7 @@ void KviKvsTreeNodeOperationSelfAnd::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfAnd::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfAnd",prefix);
+	tqDebug("%s OperationSelfAnd",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -332,7 +332,7 @@ void KviKvsTreeNodeOperationSelfDivision::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfDivision::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfDivision",prefix);
+	tqDebug("%s OperationSelfDivision",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -426,7 +426,7 @@ void KviKvsTreeNodeOperationSelfModulus::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfModulus::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfModulus",prefix);
+	tqDebug("%s OperationSelfModulus",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -521,7 +521,7 @@ void KviKvsTreeNodeOperationSelfMultiplication::contextDescription(TQString &szB
 void KviKvsTreeNodeOperationSelfMultiplication::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfMultiplication",prefix);
+	tqDebug("%s OperationSelfMultiplication",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -600,7 +600,7 @@ void KviKvsTreeNodeOperationSelfOr::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfOr::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfOr",prefix);
+	tqDebug("%s OperationSelfOr",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -670,7 +670,7 @@ void KviKvsTreeNodeOperationSelfShl::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfShl::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfShl",prefix);
+	tqDebug("%s OperationSelfShl",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -742,7 +742,7 @@ void KviKvsTreeNodeOperationSelfShr::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfShr::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfShr",prefix);
+	tqDebug("%s OperationSelfShr",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -820,7 +820,7 @@ void KviKvsTreeNodeOperationSelfSubtraction::contextDescription(TQString &szBuff
 void KviKvsTreeNodeOperationSelfSubtraction::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfSubtraction",prefix);
+	tqDebug("%s OperationSelfSubtraction",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -903,7 +903,7 @@ void KviKvsTreeNodeOperationSelfSum::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfSum::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfSum",prefix);
+	tqDebug("%s OperationSelfSum",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -988,7 +988,7 @@ void KviKvsTreeNodeOperationSelfXor::contextDescription(TQString &szBuffer)
 void KviKvsTreeNodeOperationSelfXor::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationSelfXor",prefix);
+	tqDebug("%s OperationSelfXor",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -1055,7 +1055,7 @@ void KviKvsTreeNodeOperationStringAppend::contextDescription(TQString &szBuffer)
 
 void KviKvsTreeNodeOperationStringAppend::dump(const char * prefix)
 {
-	debug("%s OperationStringAppend",prefix);
+	tqDebug("%s OperationStringAppend",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -1102,7 +1102,7 @@ void KviKvsTreeNodeOperationArrayAppend::contextDescription(TQString &szBuffer)
 
 void KviKvsTreeNodeOperationArrayAppend::dump(const char * prefix)
 {
-	debug("%s OperationArrayAppend",prefix);
+	tqDebug("%s OperationArrayAppend",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -1192,7 +1192,7 @@ void KviKvsTreeNodeOperationStringAppendWithComma::contextDescription(TQString &
 void KviKvsTreeNodeOperationStringAppendWithComma::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationStringAppendWithComma",prefix);
+	tqDebug("%s OperationStringAppendWithComma",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -1257,7 +1257,7 @@ void KviKvsTreeNodeOperationStringAppendWithSpace::contextDescription(TQString &
 void KviKvsTreeNodeOperationStringAppendWithSpace::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationStringAppendWithSpace",prefix);
+	tqDebug("%s OperationStringAppendWithSpace",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pTargetData->dump(tmp.utf8().data());
@@ -1332,7 +1332,7 @@ void KviKvsTreeNodeOperationStringTransliteration::contextDescription(TQString &
 void KviKvsTreeNodeOperationStringTransliteration::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationStringTransliteration",prefix);
+	tqDebug("%s OperationStringTransliteration",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pLeft->dump(tmp.utf8().data());
@@ -1413,7 +1413,7 @@ void KviKvsTreeNodeOperationStringSubstitution::contextDescription(TQString &szB
 void KviKvsTreeNodeOperationStringSubstitution::dump(const char * prefix)
 {
 #ifdef COMPILE_NEW_KVS
-	debug("%s OperationStringSubstitution",prefix);
+	tqDebug("%s OperationStringSubstitution",prefix);
 	TQString tmp = prefix;
 	tmp.append("  ");
 	m_pLeft->dump(tmp.utf8().data());
