@@ -36,7 +36,7 @@
 
 class KVIRC_API KviModuleManager : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviModuleManager();
