@@ -119,7 +119,7 @@ public:
 
 class KVIRC_API KviServerParser : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviServerParser();
