@@ -108,7 +108,7 @@ typedef struct _KviChannelActivityStats
 
 class KVIRC_API KviChannel : public KviWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name);
