@@ -109,7 +109,7 @@ KviImageDialog::KviImageDialog(TQWidget * par,
 	setCaption(szCaption.isEmpty() ? __tr2qs("Choose image ...") : szCaption);
 
 	m_pTimer = new TQTimer(this);
-	connect(m_pTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(heartbeat()));
+	connect(m_pTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(heartbeat()));
 
 	TQGridLayout * g = new TQGridLayout(this,4,3,5,3);
 
@@ -155,19 +155,19 @@ KviImageDialog::KviImageDialog(TQWidget * par,
 	g->addMultiCellWidget(m_pListBox,2,2,0,2);
 
 	TQPushButton * b = new TQPushButton(__tr2qs("Cancel"),this);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(cancelClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(cancelClicked()));
 	g->addWidget(b,3,1);
 
 	b = new TQPushButton(__tr2qs("Ok"),this);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(okClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(okClicked()));
 	g->addWidget(b,3,2);
 
 	g->setRowStretch(2,1);
 	g->setColStretch(0,1);
 
-	connect(m_pTypeComboBox,TQT_SIGNAL(activated(int)),this,TQT_SLOT(jobTypeSelected(int)));
-	connect(m_pListBox,TQT_SIGNAL(doubleClicked(KviTalListBoxItem *)),this,TQT_SLOT(itemDoubleClicked(KviTalListBoxItem *)));
-	connect(m_pTip,TQT_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQT_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
+	connect(m_pTypeComboBox,TQ_SIGNAL(activated(int)),this,TQ_SLOT(jobTypeSelected(int)));
+	connect(m_pListBox,TQ_SIGNAL(doubleClicked(KviTalListBoxItem *)),this,TQ_SLOT(itemDoubleClicked(KviTalListBoxItem *)));
+	connect(m_pTip,TQ_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQ_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
 
 	m_pTypeComboBox->setCurrentItem(idx);
 	jobTypeSelected(idx);
