@@ -63,7 +63,7 @@ public:
 
 class KVIRC_API KviImageDialog : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviImageDialog(TQWidget * par,
