@@ -51,7 +51,7 @@ KviMenuBar::KviMenuBar(KviFrame * par,const char * name)
 	m_pDefaultItemId = 0;
 	
 	KviTalPopupMenu * pop = new KviTalPopupMenu(this,"KVIrc");
-	connect(pop,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupMainPopup()));
+	connect(pop,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupMainPopup()));
 #ifndef Q_OS_MACX
 	addDefaultItem("&KVIrc",pop);
 #else
@@ -59,31 +59,31 @@ KviMenuBar::KviMenuBar(KviFrame * par,const char * name)
 	addDefaultItem("&IRC",pop);
 #endif //Q_OS_MACX
 	m_pRecentServersPopup = new KviTalPopupMenu(this,"recentservers");
-	connect(m_pRecentServersPopup,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupRecentServersPopup()));
-	connect(m_pRecentServersPopup,TQT_SIGNAL(activated(int)),this,TQT_SLOT(newConnectionToServer(int)));
+	connect(m_pRecentServersPopup,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupRecentServersPopup()));
+	connect(m_pRecentServersPopup,TQ_SIGNAL(activated(int)),this,TQ_SLOT(newConnectionToServer(int)));
 
 	m_pScriptItemList = 0;
 
 	pop = new KviTalPopupMenu(this,"scripting");
-	connect(pop,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupScriptingPopup()));
+	connect(pop,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupScriptingPopup()));
 	addDefaultItem(__tr2qs("Scri&pting"),pop);
 
 	pop = new KviTalPopupMenu(this,"tools");
-	connect(pop,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupToolsPopup()));
-	connect(pop,TQT_SIGNAL(activated(int)),this,TQT_SLOT(toolsPopupSelected(int)));
+	connect(pop,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupToolsPopup()));
+	connect(pop,TQ_SIGNAL(activated(int)),this,TQ_SLOT(toolsPopupSelected(int)));
 	addDefaultItem(__tr2qs("&Tools"),pop);
 
 	m_pToolbarsPopup = new KviTalPopupMenu(this,"toolbars");
-	connect(m_pToolbarsPopup,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupToolbarsPopup()));
+	connect(m_pToolbarsPopup,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupToolbarsPopup()));
 
 	pop = new KviTalPopupMenu(this,"settings");
-	connect(pop,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupSettingsPopup()));
+	connect(pop,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupSettingsPopup()));
 	addDefaultItem(__tr2qs("&Settings"),pop);
 
 	addDefaultItem(__tr2qs("&Window"),par->mdiManager()->windowPopup());
 
 	pop = new KviTalPopupMenu(this,"help");
-	connect(pop,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(setupHelpPopup()));
+	connect(pop,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(setupHelpPopup()));
 	addDefaultItem(__tr2qs("&Help"),pop);
 }
 
@@ -110,52 +110,52 @@ void KviMenuBar::setupHelpPopup()
 	help->clear();
 
 	// FIXME: Convert these to actions!
-	int id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HELP)),__tr2qs("&Help Browser (Panel)"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	int id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HELP)),__tr2qs("&Help Browser (Panel)"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_HELP_NEWSTATICWINDOW);
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MDIHELP)),__tr2qs("Help Browser (&Window)"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MDIHELP)),__tr2qs("Help Browser (&Window)"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_HELP_NEWMDIWINDOW);
 	help->insertSeparator();
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_IDEA)),__tr2qs("&Tip of the Day"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_IDEA)),__tr2qs("&Tip of the Day"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_TIP_OPEN);
 	help->insertSeparator();
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)),__tr2qs("About &KVIrc"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)),__tr2qs("About &KVIrc"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_ABOUT_ABOUTKVIRC);
 	help->insertSeparator();
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc Home&page"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc Home&page"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE);
 	if(kvi_strEqualCIN(KviLocale::localeName(),"ru",2))
 	{
-		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc Russian Home&page"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc Russian Home&page"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 		help->setItemParameter(id,KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE_RU);
 	}
 	if(kvi_strEqualCIN(KviLocale::localeName(),"fr",2))
 	{
-		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc French Home&page"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HOMEPAGE)),__tr2qs("KVIrc French Home&page"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 		help->setItemParameter(id,KVI_INTERNALCOMMAND_KVIRC_HOMEPAGE_FR);
 	}
 	help->insertSeparator();
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MESSAGE)),__tr2qs("Subscribe to the Mailing List"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MESSAGE)),__tr2qs("Subscribe to the Mailing List"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_MAILINGLIST);
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_BOMB)),__tr2qs("Report a Bug / Propose Improvements"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_BOMB)),__tr2qs("Report a Bug / Propose Improvements"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_BUGTRACK);
 	help->insertSeparator();
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc International Channel on Freenode"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc International Channel on Freenode"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_ON_FREENODE);
-	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc International Channel on IRCNet"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc International Channel on IRCNet"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_ON_IRCNET);
 	if(kvi_strEqualCIN(KviLocale::localeName(),"it",2))
 	{
 		// join #kvirc.net on azzurra
-		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc Italian Channel on AzzurraNet"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc Italian Channel on AzzurraNet"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 		help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_IT_ON_AZZURRA);
 	}
 	if(kvi_strEqualCIN(KviLocale::localeName(),"fr",2))
 	{
 		// join #kvirc-fr on freenode
-		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc French Channel on Freenode"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc French Channel on Freenode"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 		help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_FR_ON_FREENODE);
 		// join #kvirc on europnet
-		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc French Channel on EuropNet"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+		id = help->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CHANNEL)),__tr2qs("Join KVIrc French Channel on EuropNet"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 		help->setItemParameter(id,KVI_INTERNALCOMMAND_OPENURL_KVIRC_FR_ON_EUROPNET);
 	}
 	// add your localized #kvirc channels here...
@@ -170,7 +170,7 @@ void KviMenuBar::setupSettingsPopup()
 	
 	opt->insertItem(__tr2qs("Toolbars"),m_pToolbarsPopup);
 
-	int id = opt->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_STATUSBAR)),__tr2qs("Show StatusBar"),m_pFrm,TQT_SLOT(toggleStatusBar()));
+	int id = opt->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_STATUSBAR)),__tr2qs("Show StatusBar"),m_pFrm,TQ_SLOT(toggleStatusBar()));
 	opt->setItemChecked(id,m_pFrm->mainStatusBar());
 
 	
@@ -185,7 +185,7 @@ void KviMenuBar::setupSettingsPopup()
 	ACTION_POPUP_ITEM(KVI_COREACTION_EDITREGUSERS,opt)
 	
 	opt->insertSeparator();
-	opt->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FLOPPY)),__tr2qs("&Save Configuration"),g_pApp,TQT_SLOT(saveConfiguration()));
+	opt->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FLOPPY)),__tr2qs("&Save Configuration"),g_pApp,TQ_SLOT(saveConfiguration()));
 }
 
 void KviMenuBar::setupScriptingPopup()
@@ -204,7 +204,7 @@ void KviMenuBar::setupScriptingPopup()
 	ACTION_POPUP_ITEM(KVI_COREACTION_EXECUTEKVS,script)
 
 	script->insertSeparator();
-	script->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TEXTEXCLAMATIVE)),__tr2qs("Restore &Default Script"),g_pApp,TQT_SLOT(restoreDefaultScript()));
+	script->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TEXTEXCLAMATIVE)),__tr2qs("Restore &Default Script"),g_pApp,TQ_SLOT(restoreDefaultScript()));
 }
 
 void KviMenuBar::setupMainPopup()
@@ -216,7 +216,7 @@ void KviMenuBar::setupMainPopup()
 	if(m_pFrm->activeContext())
 		if(m_pFrm->activeContext()->state()==KviIrcContext::Connected)
 		{
-			int id = main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUIT)),__tr2qs("Disconnect"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+			int id = main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUIT)),__tr2qs("Disconnect"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 			main->setItemParameter(id,KVI_INTERNALCOMMAND_QUIT);
 		}
 	main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_WORLD)),__tr2qs("New &Connection To"),m_pRecentServersPopup);
@@ -225,10 +225,10 @@ void KviMenuBar::setupMainPopup()
 
 	if(m_pFrm->dockExtension())
 	{
-		int id = main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DOCKWIDGET)),__tr2qs("Hide &Dock Icon"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+		int id = main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DOCKWIDGET)),__tr2qs("Hide &Dock Icon"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 		main->setItemParameter(id,KVI_INTERNALCOMMAND_DOCKWIDGET_HIDE);
 	} else {
-		int id = main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DOCKWIDGET)),__tr2qs("Show &Dock Icon"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+		int id = main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DOCKWIDGET)),__tr2qs("Show &Dock Icon"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 		main->setItemParameter(id,KVI_INTERNALCOMMAND_DOCKWIDGET_SHOW);
 	}
 	
@@ -236,7 +236,7 @@ void KviMenuBar::setupMainPopup()
 #ifndef Q_OS_MACX
 	main->insertSeparator();
 
-	main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITAPP)),__tr2qs("&Quit"),g_pApp,TQT_SLOT(quit()));
+	main->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITAPP)),__tr2qs("&Quit"),g_pApp,TQ_SLOT(quit()));
 #endif //Q_OS_MACX
 }
 
@@ -296,10 +296,10 @@ void KviMenuBar::setupToolsPopup()
 	ACTION_POPUP_ITEM(KVI_COREACTION_SCREENSHOT,m)
 
 	// moved the old tools here
-	m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ICONMANAGER)),__tr2qs("Show &Icon Table"),g_pIconManager,TQT_SLOT(showIconWidget()));
+	m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ICONMANAGER)),__tr2qs("Show &Icon Table"),g_pIconManager,TQ_SLOT(showIconWidget()));
 #ifdef COMPILE_TDE_SUPPORT
 	int id;
-	id = m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TERMINAL)),__tr2qs("Open &Terminal"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = m->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_TERMINAL)),__tr2qs("Open &Terminal"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	m->setItemParameter(id,KVI_INTERNALCOMMAND_TERM_OPEN);
 #endif
 
@@ -370,7 +370,7 @@ bool KviMenuBar::removeMenu(const TQString &text)
    KviScriptMenuBarItem * i = findMenu(text);
    if(i)
    {
-      disconnect(i->pPopup,TQT_SIGNAL(destroyed()),this,TQT_SLOT(menuDestroyed()));
+      disconnect(i->pPopup,TQ_SIGNAL(destroyed()),this,TQ_SLOT(menuDestroyed()));
       removeItem(i->id);
       m_pScriptItemList->removeRef(i);
       return true;
@@ -402,7 +402,7 @@ void KviMenuBar::addMenu(const TQString &text,KviKvsPopupMenu * p,int index)
 	it->szPopupName = p->name();
 	it->pPopup = p;
 	it->id = insertItem(text,p,-1,index);
-	connect(p,TQT_SIGNAL(destroyed()),this,TQT_SLOT(menuDestroyed()));
+	connect(p,TQ_SIGNAL(destroyed()),this,TQ_SLOT(menuDestroyed()));
 	m_pScriptItemList->append(it);
 }
 
