@@ -45,7 +45,7 @@ class KviConsole;
 
 class KVIRC_API KviModeEditor : public KviWindowToolWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviModeEditor(TQWidget * par,KviWindowToolPageButton* button,const char * nam,KviConsole * c,const char * mode,const char * key,const char * limit);
