@@ -83,7 +83,7 @@ protected:
 class KVIRC_API KviStatusBarApplet : public TQLabel
 {
 	friend class KviStatusBar;
-	Q_OBJECT
+	TQ_OBJECT
   
 protected:
 	KviStatusBar                 * m_pStatusBar;
@@ -110,7 +110,7 @@ protected:
 
 class KviStatusBarClock : public KviStatusBarApplet
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviStatusBarClock(KviStatusBar * pParent,KviStatusBarAppletDescriptor *pDescriptor);
@@ -130,7 +130,7 @@ protected slots:
 
 class KviStatusBarConnectionTimer : public KviStatusBarApplet
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviStatusBarConnectionTimer(KviStatusBar * pParent,KviStatusBarAppletDescriptor *pDescriptor);
@@ -150,7 +150,7 @@ protected slots:
 
 class KviStatusBarSeparator : public KviStatusBarApplet
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviStatusBarSeparator(KviStatusBar * pParent,KviStatusBarAppletDescriptor *pDescriptor);
@@ -161,7 +161,7 @@ public:
 
 class KviStatusBarAwayIndicator : public KviStatusBarApplet
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviStatusBarAwayIndicator(KviStatusBar * pParent,KviStatusBarAppletDescriptor *pDescriptor);
@@ -183,7 +183,7 @@ protected slots:
 
 class KviStatusBarLagIndicator : public KviStatusBarApplet
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviStatusBarLagIndicator(KviStatusBar * pParent,KviStatusBarAppletDescriptor *pDescriptor);
