@@ -374,7 +374,7 @@ void KviTaskBarButton::drawButtonLabel(TQPainter * painter)
 		cRect.setWidth(cRect.width() + 10);
 		pPainter->drawText(cRect,TQt::AlignLeft | TQt::AlignTop,szText,-1);
 	}
-	pPainter->setClipping(FALSE);
+	pPainter->setClipping(false);
 	painter->drawPixmap(0,0,*pMemBuffer,distRect.x(),distRect.y(),iWidth,iHeight);
 }
 
@@ -1032,7 +1032,7 @@ KviTreeTaskBarListView::KviTreeTaskBarListView(TQWidget * par)
 	setShowSortIndicator(true);
 	setItemMargin(2);
 	setFrameShape(NoFrame);
-	viewport()->setMouseTracking(TRUE);
+	viewport()->setMouseTracking(true);
 	m_pPrevItem=0;
 	setHScrollBarMode(KviTalListView::AlwaysOff);
 }
@@ -1083,12 +1083,12 @@ void KviTreeTaskBarListView::contentsMousePressEvent(TQMouseEvent *e)
 
 void KviTreeTaskBarListView::sort()
 {
-	setSorting(0,TRUE);
+	setSorting(0,true);
 }
 
 void KviTreeTaskBarListView::reverseSort()
 {
-	setSorting(0,FALSE);
+	setSorting(0,false);
 }
 
 void KviTreeTaskBarListView::resizeEvent(TQResizeEvent *e)
