@@ -71,12 +71,7 @@ class TQToolButton;
 class TQSimpleRichText;
 class TQPushButton;
 
-#ifdef COMPILE_USE_QT4
-	#include <tq3simplerichtext.h>
-	#define TQSimpleRichText Q3SimpleRichText
-#else
 	#include <tqsimplerichtext.h>
-#endif
 
 
 
@@ -103,7 +98,7 @@ public:
 
 class KviActionEditorListView : public KviTalListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviActionEditorListView(TQWidget * pParent);
@@ -116,7 +111,7 @@ class KviActionEditor;
 
 class KviSingleActionEditor : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviSingleActionEditor(TQWidget * par,KviActionEditor * ed);
@@ -163,7 +158,7 @@ class TQSplitter;
 class KviActionEditor : public TQWidget
 {
 	friend class KviActionEditorWindow;
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviActionEditor(TQWidget * par);
@@ -191,7 +186,7 @@ protected slots:
 
 class KviActionEditorWindow : public KviWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviActionEditorWindow(KviFrame * lpFrm);
