@@ -34,7 +34,7 @@ class KviScriptEditor;
 
 class KviCodeTester : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviCodeTester(TQWidget * par);
@@ -50,7 +50,7 @@ private slots:
 
 class KviCodeTesterWindow : public KviWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviCodeTesterWindow(KviFrame * lpFrm);
