@@ -291,10 +291,10 @@ void KviDccBroker::handleChatRequest(KviDccDescriptor * dcc)
 		KviDccAcceptBox * box = new KviDccAcceptBox(this,dcc,tmp,caption);
 
 		m_pBoxList->append(box);
-		connect(box,TQT_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(executeChat(KviDccBox *,KviDccDescriptor *)));
-		connect(box,TQT_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(executeChat(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
 		box->show();
 	} else {
 		// auto accept
@@ -345,10 +345,10 @@ void KviDccBroker::activeVoiceManage(KviDccDescriptor * dcc)
 
 		KviDccAcceptBox * box = new KviDccAcceptBox(this,dcc,tmp,__tr2qs_ctx("DCC VOICE request","dcc"));
 		m_pBoxList->append(box);
-		connect(box,TQT_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(activeVoiceExecute(KviDccBox *,KviDccDescriptor *)));
-		connect(box,TQT_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(activeVoiceExecute(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
 		box->show();
 	} else {
 		// auto accept
@@ -416,10 +416,10 @@ void KviDccBroker::activeCanvasManage(KviDccDescriptor * dcc)
 
 		KviDccAcceptBox * box = new KviDccAcceptBox(this,dcc,tmp,__tr2qs_ctx("DCC CANVAS request","dcc"));
 		m_pBoxList->append(box);
-		connect(box,TQT_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(activeCanvasExecute(KviDccBox *,KviDccDescriptor *)));
-		connect(box,TQT_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(activeCanvasExecute(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
 		box->show();
 	} else {
 		// auto accept
@@ -544,10 +544,10 @@ void KviDccBroker::recvFileManage(KviDccDescriptor * dcc)
 
 		KviDccAcceptBox * box = new KviDccAcceptBox(this,dcc,tmp,title);
 		m_pBoxList->append(box);
-		connect(box,TQT_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(chooseSaveFileName(KviDccBox *,KviDccDescriptor *)));
-		connect(box,TQT_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
-				this,TQT_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(accepted(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(chooseSaveFileName(KviDccBox *,KviDccDescriptor *)));
+		connect(box,TQ_SIGNAL(rejected(KviDccBox *,KviDccDescriptor *)),
+				this,TQ_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
 		box->show();
 	} else {
 		// auto accept
@@ -685,12 +685,12 @@ void KviDccBroker::renameOverwriteResume(KviDccBox *box,KviDccDescriptor * dcc)
 
 			KviDccRenameBox * box = new KviDccRenameBox(this,dcc,tmp,bDisableResume);
 			m_pBoxList->append(box);
-			connect(box,TQT_SIGNAL(renameSelected(KviDccBox *,KviDccDescriptor *)),
-					this,TQT_SLOT(renameDccSendFile(KviDccBox *,KviDccDescriptor *)));
-			connect(box,TQT_SIGNAL(overwriteSelected(KviDccBox *,KviDccDescriptor *)),
-					this,TQT_SLOT(recvFileExecute(KviDccBox *,KviDccDescriptor *)));
-			connect(box,TQT_SIGNAL(cancelSelected(KviDccBox *,KviDccDescriptor *)),
-					this,TQT_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
+			connect(box,TQ_SIGNAL(renameSelected(KviDccBox *,KviDccDescriptor *)),
+					this,TQ_SLOT(renameDccSendFile(KviDccBox *,KviDccDescriptor *)));
+			connect(box,TQ_SIGNAL(overwriteSelected(KviDccBox *,KviDccDescriptor *)),
+					this,TQ_SLOT(recvFileExecute(KviDccBox *,KviDccDescriptor *)));
+			connect(box,TQ_SIGNAL(cancelSelected(KviDccBox *,KviDccDescriptor *)),
+					this,TQ_SLOT(cancelDcc(KviDccBox *,KviDccDescriptor *)));
 			box->show();
 			return;
 		} else {
