@@ -21,7 +21,6 @@
 //
 
 #include "kvi_settings.h"
-#ifndef COMPILE_USE_QT4
 
 #include "kvi_app.h"
 #include "kvi_module.h"
@@ -111,7 +110,7 @@ KviDockWidget::KviDockWidget(KviFrame * frm,const char * name)
 	m_iOther    = 0;
 	
 	m_pFlashingTimer = new TQTimer(this,"flashing_timer");
-	connect( m_pFlashingTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(flashingTimerShot()) );
+	connect( m_pFlashingTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(flashingTimerShot()) );
 	m_bFlashed=0;
 	g_pDockWidgetList->append(this);
 	m_pFrm = frm;
@@ -123,20 +122,15 @@ KviDockWidget::KviDockWidget(KviFrame * frm,const char * name)
 	createTaskbarIcon();
 #else //!COMPILE_ON_WINDOWS
 	setMinimumSize(22,22);
-	#ifndef COMPILE_USE_QT4
-		setBackgroundMode(X11ParentRelative);
-	#endif
+	setBackgroundMode(X11ParentRelative);
 	#ifdef COMPILE_TDE_SUPPORT
 		KWin::setSystemTrayWindowFor(winId(),frm->winId());
 	#endif
 #endif //!COMPILE_ON_WINDOWS
 
-#ifdef COMPILE_USE_QT4
-	m_pSysTrayIcon = new TQSystemTrayIcon(m_pFrm);
-#endif
 
 	m_pTip = new KviDynamicToolTip(this,"dock_tooltip");
-	connect(m_pTip,TQT_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQT_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
+	connect(m_pTip,TQ_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQ_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
 	
 	m_pAwayPopup = new KviTalPopupMenu(this);
 	
@@ -145,28 +139,26 @@ KviDockWidget::KviDockWidget(KviFrame * frm,const char * name)
 	m_pContextPopup->insertTitle(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)),__tr2qs("KVIrc"));
 #else
 	m_pContextPopup = new KviTalPopupMenu(this);
-#ifndef COMPILE_USE_QT4
 	TQLabel * l = new TQLabel(__tr2qs("KVIrc"),m_pContextPopup);
 	l->setFrameStyle(TQFrame::Raised | TQFrame::StyledPanel);
 	m_pContextPopup->insertItem(l);
-#endif
 #endif
 	m_pContextPopup->setCaption(__tr2qs("Context"));
 	m_iAwayMenuId = m_pContextPopup->insertItem ( __tr2qs("Away"), m_pAwayPopup);
 	m_pContextPopup->changeItem(m_iAwayMenuId,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_AWAY)),__tr2qs("Away"));
 	
-	int id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_OPTIONS)),__tr2qs("&Configure KVIrc..."),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	int id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_OPTIONS)),__tr2qs("&Configure KVIrc..."),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	m_pContextPopup->setItemParameter(id,KVI_INTERNALCOMMAND_OPTIONS_DIALOG);
-	id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)),__tr2qs("&About KVIrc"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_KVIRC)),__tr2qs("&About KVIrc"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	m_pContextPopup->setItemParameter(id,KVI_INTERNALCOMMAND_ABOUT_ABOUTKVIRC);
 	m_pContextPopup->insertSeparator();
-	m_iToggleFrame = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RAW)),TQString(""),this,TQT_SLOT(toggleParentFrame()));
+	m_iToggleFrame = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RAW)),TQString(""),this,TQ_SLOT(toggleParentFrame()));
 	m_pContextPopup->insertSeparator();
-	id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DOCKWIDGET)),__tr2qs("Un&dock"),m_pFrm,TQT_SLOT(executeInternalCommand(int)));
+	id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DOCKWIDGET)),__tr2qs("Un&dock"),m_pFrm,TQ_SLOT(executeInternalCommand(int)));
 	m_pContextPopup->setItemParameter(id,KVI_INTERNALCOMMAND_DOCKWIDGET_HIDE);
-	id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITAPP)),__tr2qs("&Quit"),g_pApp,TQT_SLOT(quit()));
+	id = m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUITAPP)),__tr2qs("&Quit"),g_pApp,TQ_SLOT(quit()));
 	m_pContextPopup->setAccel(__tr2qs("Ctrl+Q"),id);
-	connect(m_pContextPopup,TQT_SIGNAL(aboutToShow()),this,TQT_SLOT(fillContextPopup()));
+	connect(m_pContextPopup,TQ_SIGNAL(aboutToShow()),this,TQ_SLOT(fillContextPopup()));
 }
 
 
@@ -379,8 +371,8 @@ void KviDockWidget::tipRequest(KviDynamicToolTip *tip,const TQPoint &pnt)
 
 void KviDockWidget::mousePressEvent(TQMouseEvent *e)
 {
-	if(e->button() & Qt::LeftButton)toggleParentFrame();
-	else if(e->button() & Qt::RightButton)
+	if(e->button() & TQt::LeftButton)toggleParentFrame();
+	else if(e->button() & TQt::RightButton)
 		m_pContextPopup->popup(mapToGlobal(e->pos()));
 }
 
@@ -425,10 +417,10 @@ void KviDockWidget::fillContextPopup()
 		m_pContextPopup->setItemVisible(m_iAwayMenuId,true);
 		m_pAwayPopup->clear();
 		
-		int iAllAway=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on all"),this,TQT_SLOT(doAway(int)));
+		int iAllAway=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on all"),this,TQ_SLOT(doAway(int)));
 		m_pAwayPopup->setItemParameter(iAllAway,-1);
 		
-		int iAllUnaway=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on all"),this,TQT_SLOT(doAway(int)));
+		int iAllUnaway=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on all"),this,TQ_SLOT(doAway(int)));
 		m_pAwayPopup->setItemParameter(iAllUnaway,-2);
 		
 		int iSeparator=m_pAwayPopup->insertSeparator();
@@ -447,10 +439,10 @@ void KviDockWidget::fillContextPopup()
 					int id;
 					if(pConsole->connection()->userInfo()->isAway())
 					{
-						id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on %1").arg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
+						id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on %1").arg(pConsole->currentNetworkName()),this,TQ_SLOT(doAway(int)));
 						bAllUnaway=0;
 					} else {
-						id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on %1").arg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
+						id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on %1").arg(pConsole->currentNetworkName()),this,TQ_SLOT(doAway(int)));
 						bAllAway=0;
 					}
 					m_pAwayPopup->setItemParameter(id,pConsole->ircContextId());
@@ -614,30 +606,16 @@ void KviDockWidget::grabActivityInfo()
 
 void KviDockWidget::paintEvent(TQPaintEvent * event)
 {
-#ifdef COMPILE_USE_QT4
-	TQPainter thisRestrictionOfTQt4IsNotNice(this);
-	if(m_bFlashed)
-	{
-		erase();
-		thisRestrictionOfTQt4IsNotNice.drawPixmap(4,4,16,16,*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MESSAGE)),0,0,16,16);
-	} else {
-		thisRestrictionOfTQt4IsNotNice.drawPixmap(0,0,12,12,m_iOther ? ((m_iOther == 2) ? *g_pDock3 : *g_pDock2) : *g_pDock1,0,0,12,12);
-		thisRestrictionOfTQt4IsNotNice.drawPixmap(0,12,12,12,m_iConsoles ? ((m_iConsoles == 2) ? *g_pDock3 : *g_pDock2) : *g_pDock1,0,12,12,12);
-		thisRestrictionOfTQt4IsNotNice.drawPixmap(12,0,12,12,m_iQueries ? ((m_iQueries == 2) ? *g_pDock3 : *g_pDock2) : *g_pDock1,12,0,12,12);
-		thisRestrictionOfTQt4IsNotNice.drawPixmap(12,12,12,12,m_iChannels ? ((m_iChannels == 2) ? *g_pDock3 : *g_pDock2) : *g_pDock1,12,12,12,12);
-	}
-#else
 	if(m_bFlashed)
 	{
 		erase();
 		bitBlt(this,4,4,g_pIconManager->getSmallIcon(KVI_SMALLICON_MESSAGE),0,0,16,16);
 	} else {
-		bitBlt(TQT_TQPAINTDEVICE(this),0,0,TQT_TQPAINTDEVICE(m_iOther ? ((m_iOther == 2) ? g_pDock3 : g_pDock2) : g_pDock1),0,0,12,12,TQt::CopyROP,false);
-		bitBlt(TQT_TQPAINTDEVICE(this),0,12,TQT_TQPAINTDEVICE(m_iConsoles ? ((m_iConsoles == 2) ? g_pDock3 : g_pDock2) : g_pDock1),0,12,12,12,TQt::CopyROP,false);
-		bitBlt(TQT_TQPAINTDEVICE(this),12,0,TQT_TQPAINTDEVICE(m_iQueries ? ((m_iQueries == 2) ? g_pDock3 : g_pDock2) : g_pDock1),12,0,12,12,TQt::CopyROP,false);
-		bitBlt(TQT_TQPAINTDEVICE(this),12,12,TQT_TQPAINTDEVICE(m_iChannels ? ((m_iChannels == 2) ? g_pDock3 : g_pDock2) : g_pDock1),12,12,12,12,TQt::CopyROP,false);
+		bitBlt(this,0,0,m_iOther ? ((m_iOther == 2) ? g_pDock3 : g_pDock2) : g_pDock1,0,0,12,12,TQt::CopyROP,false);
+		bitBlt(this,0,12,m_iConsoles ? ((m_iConsoles == 2) ? g_pDock3 : g_pDock2) : g_pDock1,0,12,12,12,TQt::CopyROP,false);
+		bitBlt(this,12,0,m_iQueries ? ((m_iQueries == 2) ? g_pDock3 : g_pDock2) : g_pDock1,12,0,12,12,TQt::CopyROP,false);
+		bitBlt(this,12,12,m_iChannels ? ((m_iChannels == 2) ? g_pDock3 : g_pDock2) : g_pDock1,12,12,12,12,TQt::CopyROP,false);
 	}
-#endif
 }
 
 
@@ -853,4 +831,3 @@ KVIRC_MODULE(
 
 #include "libkvidockwidget_qt3.moc"
 
-#endif
