@@ -70,7 +70,7 @@ KviEventEditor::KviEventEditor(TQWidget * par)
 {
 	TQGridLayout * l = new TQGridLayout(this,1,1,2,2);
 
-	TQSplitter * spl = new TQSplitter(Qt::Horizontal,this);
+	TQSplitter * spl = new TQSplitter(TQt::Horizontal,this);
 	spl->setOpaqueResize(false);
 
 	l->addWidget(spl,0,0);
@@ -83,7 +83,7 @@ KviEventEditor::KviEventEditor(TQWidget * par)
 	m_pListView->setRootIsDecorated(true);
 
 	TQPushButton * pb = new TQPushButton(__tr2qs("&Export All To..."),boxi);
-	connect(pb,TQT_SIGNAL(clicked()),this,TQT_SLOT(exportAllEvents()));
+	connect(pb,TQ_SIGNAL(clicked()),this,TQ_SLOT(exportAllEvents()));
 
 	KviTalVBox * box = new KviTalVBox(spl);
 	m_pNameEditor = new TQLineEdit(box);
@@ -129,9 +129,9 @@ void KviEventEditor::oneTimeSetup()
 
 	m_pContextPopup = new KviTalPopupMenu(this);
 
-	connect(m_pListView,TQT_SIGNAL(selectionChanged(KviTalListViewItem *)),this,TQT_SLOT(selectionChanged(KviTalListViewItem *)));
-	connect(m_pListView,TQT_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),
-		this,TQT_SLOT(itemPressed(KviTalListViewItem *,const TQPoint &,int)));
+	connect(m_pListView,TQ_SIGNAL(selectionChanged(KviTalListViewItem *)),this,TQ_SLOT(selectionChanged(KviTalListViewItem *)));
+	connect(m_pListView,TQ_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),
+		this,TQ_SLOT(itemPressed(KviTalListViewItem *,const TQPoint &,int)));
 }
 
 void KviEventEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt,int col)
@@ -147,27 +147,27 @@ void KviEventEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt,int c
 			if(!(((KviEventHandlerListViewItem *)it)->m_bEnabled))
 				m_pContextPopup->insertItem(
 					*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HANDLER)),
-					__tr2qs("&Enable Handler"),this,TQT_SLOT(toggleCurrentHandlerEnabled()));
+					__tr2qs("&Enable Handler"),this,TQ_SLOT(toggleCurrentHandlerEnabled()));
 			else
 				m_pContextPopup->insertItem(
 					*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HANDLERDISABLED)),
-					__tr2qs("&Disable Handler"),this,TQT_SLOT(toggleCurrentHandlerEnabled()));
+					__tr2qs("&Disable Handler"),this,TQ_SLOT(toggleCurrentHandlerEnabled()));
 
 			//m_pContextPopup->setItemChecked(id,((KviEventHandlerListViewItem *)it)->m_bEnabled);
 
 			m_pContextPopup->insertItem(
 					*(g_pIconManager->getSmallIcon(KVI_SMALLICON_QUIT)),
 					__tr2qs("Re&move Handler"),
-					this,TQT_SLOT(removeCurrentHandler()));
+					this,TQ_SLOT(removeCurrentHandler()));
 			m_pContextPopup->insertItem(
 					*(g_pIconManager->getSmallIcon(KVI_SMALLICON_FOLDER)),
 					__tr2qs("&Export Handler To..."),
-					this,TQT_SLOT(exportCurrentHandler()));
+					this,TQ_SLOT(exportCurrentHandler()));
 		} else {
 			m_pContextPopup->insertItem(
 				*(g_pIconManager->getSmallIcon(KVI_SMALLICON_HANDLER)),
 				__tr2qs("&New Handler"),
-				this,TQT_SLOT(addHandlerForCurrentEvent()));
+				this,TQ_SLOT(addHandlerForCurrentEvent()));
 		}
 
 		m_pContextPopup->popup(pnt);
@@ -430,17 +430,17 @@ KviEventEditorWindow::KviEventEditorWindow(KviFrame * lpFrm)
 	TQGridLayout * g = new TQGridLayout(m_pBase,1,4,4,4);
 
 	TQPushButton * btn = new TQPushButton(__tr2qs("&OK"),m_pBase);
-	connect(btn,TQT_SIGNAL(clicked()),this,TQT_SLOT(okClicked()));
+	connect(btn,TQ_SIGNAL(clicked()),this,TQ_SLOT(okClicked()));
 	btn->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g->addWidget(btn,0,1);
 
 	btn = new TQPushButton(__tr2qs("&Apply"),m_pBase);
-	connect(btn,TQT_SIGNAL(clicked()),this,TQT_SLOT(applyClicked()));
+	connect(btn,TQ_SIGNAL(clicked()),this,TQ_SLOT(applyClicked()));
 	btn->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g->addWidget(btn,0,2);
 
 	btn = new TQPushButton(__tr2qs("Cancel"),m_pBase);
-	connect(btn,TQT_SIGNAL(clicked()),this,TQT_SLOT(cancelClicked()));
+	connect(btn,TQ_SIGNAL(clicked()),this,TQ_SLOT(cancelClicked()));
 	btn->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DISCARD)));
 	g->addWidget(btn,0,3);
 
