@@ -208,7 +208,7 @@ bool KviFileTransferWindow::eventFilter( TQObject *obj, TQEvent *ev )
 				if(m_pListView->currentItem())
 				{
 					delete m_pListView->currentItem();
-					return TRUE;
+					return true;
 				}
 				break;
 		}
@@ -589,7 +589,7 @@ void KviFileTransferWindow::openLocalFileFolder()
 	if(!t)return;
 	TQString tmp = t->localFileName();
 	if(tmp.isEmpty())return;
-	tmp=TQFileInfo(tmp).dirPath(TRUE);
+	tmp=TQFileInfo(tmp).dirPath(true);
 	tmp.replace('/','\\');
 	tmp.prepend("explorer.exe ");
 	WinExec(tmp.local8Bit().data(), SW_MAXIMIZE);
