@@ -39,7 +39,7 @@ class KviTalPopupMenu;
 class KviHttpFileTransfer : public KviFileTransfer
 {
 	enum GeneralStatus { Initializing, Connecting, Downloading, Success, Failure };
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviHttpFileTransfer();
