@@ -42,7 +42,7 @@ MP_IMPLEMENT_DESCRIPTOR(
 	KviJukInterface,
 	"juk",
 	__tr2qs_ctx(
-		"An interface to the Juk KDE media player."
+		"An interface to the Juk TDE media player."
 		,
 		"mediaplayer"
 	)
