@@ -59,7 +59,7 @@ extern kvi_time_t g_tNotifierDisabledUntil;
 
 class KviNotifierWindow : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviNotifierWindow();
