@@ -112,7 +112,7 @@ bool KviKvsObject_layout::init(KviKvsRunTimeContext * pContext,KviKvsVariantList
 		pContext->warning(__tr2qs("The parent of a layout must be a widget!"));
 		return false;
 	}
-	setObject(TQT_TQOBJECT(new TQGridLayout(w)));
+	setObject(new TQGridLayout(w));
 	return true;
 }
 
