@@ -106,9 +106,9 @@ static int mod_cod[] =	{
 		Sets the editor to be read-only if bReadOnly is 1 or
 		removes the read-only status is ReadOnly is 0
 		!fn: <boolean> $atBeginning()
-		Returns 1(TRUE) if the cursor is placed at the beginning of the text; otherwise returns 0(FALSE).
+		Returns true if the cursor is placed at the beginning of the text; otherwise returns false.
 		!fn: <boolean> $atEnd()
-		Returns 1(TRUE) if the cursor is placed at the end of the text; otherwise returns 0(FALSE).
+		Returns true if the cursor is placed at the end of the text; otherwise returns false.
 		!fn: $setWordWrap(<wrap_mode:string>)
 		Sets the word wrap mode to mode. Valid Values are:[br]
 		- NoWrap - Do not wrap the text.[br]
@@ -144,11 +144,11 @@ static int mod_cod[] =	{
 		!fn: $setUnderline(<bUnderline:boolean>)
 		If the bool value is 1 sets the current format to underline; otherwise, if it's 0 sets the current format to no-underline.
 		!fn: <boolean> $italic()
-		Returns 1(TRUE) if the current format is italic; otherwise returns 0(FALSE).
+		Returns true if the current format is italic; otherwise returns false.
 		!fn: <boolean> $bold()
-		Returns 1(TRUE) if the current format is bold; otherwise returns 0(FALSE).
+		Returns true if the current format is bold; otherwise returns false.
 		!fn: <boolean> $underline()
-		Returns 1(TRUE) if the current format is underline; otherwise returns 0(FALSE).
+		Returns true if the current format is underline; otherwise returns false.
 		!fn: $zoomIn(<zoom_range:integer>)
 		Zooms in on the text by making the base font size range points larger.
 		!fn: $zoomOut(<zoom_range:integer>)
@@ -166,7 +166,7 @@ static int mod_cod[] =	{
 		!fn: $setUndoDepth(<undo_depth:integer>)
 		Sets the depth of the undo history to x.
 		!fn: <boolean> $isUndoRedoEnabled()
-		Returns 1 (TRUE) if undo/redo is enabled; otherwise returns 0 (FALSE).
+		Returns true if undo/redo is enabled; otherwise returns false.
 		!fn: <integer> $undoDepth()
 		Returns the depth of the undo history.
 		!fn: $indent()
@@ -188,7 +188,7 @@ static int mod_cod[] =	{
 		- array(red:integer,green:integer,blue:integer)
 		- red:integer,green:integer,blue:integer.
 		!fn: $setModified(<bModified:boolean>)
-		Sets whether the document has been modified by the user. Valid Values are 1(TRUE) or 0(FALSE)
+		Sets whether the document has been modified by the user. Valid Values are true or false
 		!fn: $insertParagraph(<text:string>,<paragraph:integer>)
 		Inserts text as a new paragraph at position <paragraph>.
 		!fn: $removeParagraph(<paragraph:integer>)
@@ -210,9 +210,9 @@ static int mod_cod[] =	{
 		!fn: $loadFile(<path:string>)
 		Load the file specified in the <path>, also html files.
 		!fn: <boolean> $isUndoAvailable ()
-		Returns 1(TRUE) if undo is available; otherwise returns 0(FALSE).
+		Returns true if undo is available; otherwise returns false.
 		!fn: <boolean> $isRedoAvailable ()
-		Returns 1(TRUE) if redo is available; otherwise returns 0(FALSE).
+		Returns true if redo is available; otherwise returns false.
 		!fn: $setAlignment(<alignment:string>)
 		Sets the alignment of the current paragraph to <alignment>. Valid values are:[br]
 		- AlignAuto - Aligns according to the language.[br]
