@@ -1,6 +1,5 @@
 #ifndef _CLASS_MULTILINEEDIT_H_
 #define _CLASS_MULTILINEEDIT_H_
-//vim: ts=8
 //   File : class_multilineedit.cpp
 //   Creation date : Mon Feb 19 00:45:34 CET by Krzysztof Godlewski
 //
@@ -31,7 +30,7 @@
 
 class KviKvsObject_mledit : public KviKvsObject_widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KVSO_DECLARE_OBJECT(KviKvsObject_mledit)
