@@ -31,7 +31,7 @@
 
 class KviKvsObject_popupmenu : public KviKvsObject_widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KVSO_DECLARE_OBJECT(KviKvsObject_popupmenu)
