@@ -28,26 +28,18 @@
 
 
 #include "object_macros.h"
-#ifdef COMPILE_USE_QT4
-#include <tq3process.h>
-#else
 #include <tqprocess.h>
-#endif
 
 
 class KviKvsObject_process : public KviKvsObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KVSO_DECLARE_OBJECT(KviKvsObject_process)
 protected:
 
-#ifdef COMPILE_USE_QT4
-	Q3Process * m_pProcess;
-#else
 	TQProcess * m_pProcess;
-#endif
 
 public:
 
