@@ -30,7 +30,7 @@
 
 class KviKvsObject_slider : public KviKvsObject_widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KVSO_DECLARE_OBJECT(KviKvsObject_slider)
