@@ -29,7 +29,7 @@
 
 class KviKvsObject_tabwidget : public KviKvsObject_widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KVSO_DECLARE_OBJECT(KviKvsObject_tabwidget)
