@@ -110,7 +110,7 @@ const int widgettypes_cod[] = {
 		See also [classfnc]$show[/classfnc]() and [classfnc]$isVisible[/classfnc].
 		!fn: $repaint(<bool erase>)
 		Repaints the widget directly by calling [classfnc]$paintEvent[/classfnc]() immediately.[br]
-		If erase is TRUE, erases the widget before the $paintEvent() call.
+		If erase is true, erases the widget before the $paintEvent() call.
 		!fn: $x()
 		Returns the x coordinate of the upper-left corner
 		of this widget relative to the parent widget,
@@ -1514,12 +1514,12 @@ bool KviKvsObject_widget::function_setFont(KviKvsObjectFunctionCall *c)
 	TQFont font=widget()->font();
 	font.setFamily(szFamily);
 	font.setPointSize(uSize);
-	if(KviTQString::equalCI(szStyle,"italic")) font.setItalic(TRUE);
-	else if(KviTQString::equalCI(szStyle,"bold")) font.setBold(TRUE);
-	else if(KviTQString::equalCI(szStyle,"underline"))font.setUnderline(TRUE);
-	else if(KviTQString::equalCI(szStyle,"overline")) font.setOverline(TRUE);
-	else if(KviTQString::equalCI(szStyle,"strikeout"))font.setStrikeOut(TRUE);
-	else if(KviTQString::equalCI(szStyle,"fixedpitch")) font.setFixedPitch(TRUE);
+	if(KviTQString::equalCI(szStyle,"italic")) font.setItalic(true);
+	else if(KviTQString::equalCI(szStyle,"bold")) font.setBold(true);
+	else if(KviTQString::equalCI(szStyle,"underline"))font.setUnderline(true);
+	else if(KviTQString::equalCI(szStyle,"overline")) font.setOverline(true);
+	else if(KviTQString::equalCI(szStyle,"strikeout"))font.setStrikeOut(true);
+	else if(KviTQString::equalCI(szStyle,"fixedpitch")) font.setFixedPitch(true);
 	else c->warning(__tr2qs("Unknown style '%Q'"),&szStyle);
 	widget()->setFont(font);
 	return true;
