@@ -36,7 +36,7 @@
 
 class KviKvsObject_wrapper : public KviKvsObject_widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KVSO_DECLARE_OBJECT(KviKvsObject_wrapper)
