@@ -30,7 +30,7 @@ class TQPushButton;
 
 class KviOptionsWidgetContainer : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviOptionsWidgetContainer(TQWidget * par,bool bModal = false);
