@@ -178,7 +178,7 @@ KviOptionsDialog::KviOptionsDialog(TQWidget * par,const TQString &szGroup)
 	setCaption(szCaption);
 
 	TQGridLayout * g1 = new TQGridLayout(this,2,5,8,8);
-	TQSplitter * spl = new TQSplitter(Qt::Horizontal,this);
+	TQSplitter * spl = new TQSplitter(TQt::Horizontal,this);
 
 	g1->addMultiCellWidget(spl,0,0,0,4);
 
@@ -192,19 +192,19 @@ KviOptionsDialog::KviOptionsDialog(TQWidget * par,const TQString &szGroup)
 	m_pListView->header()->hide();
 	m_pListView->setRootIsDecorated(true);
 	m_pListView->setSorting(-1);
-	connect(m_pListView,TQT_SIGNAL(selectionChanged(KviTalListViewItem *)),this,TQT_SLOT(listViewItemSelectionChanged(KviTalListViewItem *)));
+	connect(m_pListView,TQ_SIGNAL(selectionChanged(KviTalListViewItem *)),this,TQ_SLOT(listViewItemSelectionChanged(KviTalListViewItem *)));
 
 	KviTalHBox * hbox = new KviTalHBox(vbox);
 	vbox->setSpacing(2);
 	vbox->setMargin(0);
 
 	m_pSearchLineEdit = new TQLineEdit(hbox);
-	connect(m_pSearchLineEdit,TQT_SIGNAL(returnPressed()),this,TQT_SLOT(searchClicked()));
+	connect(m_pSearchLineEdit,TQ_SIGNAL(returnPressed()),this,TQ_SLOT(searchClicked()));
 	m_pSearchButton = new KviStyledToolButton(hbox);
 	m_pSearchButton->setUsesBigPixmap(false);
 	m_pSearchButton->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_SEARCH)));
-	connect(m_pSearchButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(searchClicked()));
-	connect(m_pSearchLineEdit,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(searchLineEditTextChanged(const TQString &)));
+	connect(m_pSearchButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(searchClicked()));
+	connect(m_pSearchLineEdit,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(searchLineEditTextChanged(const TQString &)));
 
 #ifdef COMPILE_INFO_TIPS
 	TQString szTip = __tr2qs_ctx("<p>This is the search tool for this options dialog.</p>" \
@@ -240,14 +240,14 @@ KviOptionsDialog::KviOptionsDialog(TQWidget * par,const TQString &szGroup)
 
 	TQPushButton * b = new TQPushButton(__tr2qs_ctx("&OK","options"),this,"btnok");
 	KviTalToolTip::add(b,__tr2qs_ctx("Close this dialog, accepting all changes.","options"));
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(okClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(okClicked()));
 	//b->setMinimumWidth(whatIsThisWidth);
 	b->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g1->addWidget(b,1,2);	
 
 	b = new TQPushButton(__tr2qs_ctx("&Apply","options"),this,"btnapply");
 	KviTalToolTip::add(b,__tr2qs_ctx("Commit all changes immediately.","options"));
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(applyClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(applyClicked()));
 	b->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g1->addWidget(b,1,3);
 
@@ -255,7 +255,7 @@ KviOptionsDialog::KviOptionsDialog(TQWidget * par,const TQString &szGroup)
 	KviTalToolTip::add(b,__tr2qs_ctx("Close this dialog, discarding all changes.","options"));
 	b->setDefault(true);
 	//b->setMinimumWidth(whatIsThisWidth);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(cancelClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(cancelClicked()));
 	b->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DISCARD)));
 	g1->addWidget(b,1,4);
 
@@ -280,7 +280,7 @@ KviOptionsDialog::KviOptionsDialog(TQWidget * par,const TQString &szGroup)
 	}
 
 	KviAccel *a = new KviAccel( this );
-        a->connectItem( a->insertItem(TQt::Key_Escape), this,TQT_SLOT(close()) );
+        a->connectItem( a->insertItem(TQt::Key_Escape), this,TQ_SLOT(close()) );
 	
 }
 
