@@ -70,7 +70,7 @@ KviDccAdvancedOptionsWidget::KviDccAdvancedOptionsWidget(TQWidget * parent)
 {
 	createLayout(5,1);
 
-	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Network Properties","options"));
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,TQt::Horizontal,__tr2qs_ctx("Network Properties","options"));
 	
 	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Use user-defined address or network interface","options"),KviOption_boolDccListenOnSpecifiedInterfaceByDefault);
 
@@ -89,7 +89,7 @@ KviDccAdvancedOptionsWidget::KviDccAdvancedOptionsWidget(TQWidget * parent)
 		"If you set it to <b>0.0.0.0</b>, KVIrc will try to use the first available IPv4 interface</center>","options"));
 #endif
 
-	connect(b,TQT_SIGNAL(toggled(bool)),s,TQT_SLOT(setEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),s,TQ_SLOT(setEnabled(bool)));
 
  	b = addBoolSelector(g,__tr2qs_ctx("Use user-defined port range","options"),KviOption_boolUserDefinedPortRange);
 
@@ -100,10 +100,10 @@ KviDccAdvancedOptionsWidget::KviDccAdvancedOptionsWidget(TQWidget * parent)
 	KviTalHBox * hb = new KviTalHBox(g);
 	hb->setSpacing(4);
 	KviUIntSelector * u = addUIntSelector(hb,__tr2qs_ctx("Lowest port:","options"),KviOption_uintDccMinPort,1,65535,5000,KVI_OPTION_BOOL(KviOption_boolUserDefinedPortRange));
-	connect(b,TQT_SIGNAL(toggled(bool)),u,TQT_SLOT(setEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),u,TQ_SLOT(setEnabled(bool)));
 
 	u = addUIntSelector(hb,__tr2qs_ctx("Highest port:","options"),KviOption_uintDccMaxPort,1,65535,30000,KVI_OPTION_BOOL(KviOption_boolUserDefinedPortRange));
-	connect(b,TQT_SIGNAL(toggled(bool)),u,TQT_SLOT(setEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),u,TQ_SLOT(setEnabled(bool)));
 
 	b = addBoolSelector(g,__tr2qs_ctx("Send a fixed address in requests","options"),KviOption_boolDccSendFakeAddressByDefault);
 
@@ -113,7 +113,7 @@ KviDccAdvancedOptionsWidget::KviDccAdvancedOptionsWidget(TQWidget * parent)
 #endif
 
 	s = addStringSelector(g,__tr2qs_ctx("Send address/interface:","options"),KviOption_stringDefaultDccFakeAddress,KVI_OPTION_BOOL(KviOption_boolDccSendFakeAddressByDefault));
-	connect(b,TQT_SIGNAL(toggled(bool)),s,TQT_SLOT(setEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),s,TQ_SLOT(setEnabled(bool)));
 
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(s,__tr2qs_ctx("<center>This is the fixed address that will be sent with all DCC requests if you enable the option above.</center>","options"));
@@ -122,7 +122,7 @@ KviDccAdvancedOptionsWidget::KviDccAdvancedOptionsWidget(TQWidget * parent)
 	KviBoolSelector * b2;
 	b2 = addBoolSelector(g,__tr2qs_ctx("Guess address from IRC server if unroutable","options"),
 									KviOption_boolDccGuessIpFromServerWhenLocalIsUnroutable,!KVI_OPTION_BOOL(KviOption_boolDccSendFakeAddressByDefault));
-	connect(b,TQT_SIGNAL(toggled(bool)),b2,TQT_SLOT(setNotEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),b2,TQ_SLOT(setNotEnabled(bool)));
 
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b2,__tr2qs_ctx("<center>You can enable this option if you are behind a router that forwards all or a range of ports.<br>" \
@@ -139,7 +139,7 @@ KviDccAdvancedOptionsWidget::KviDccAdvancedOptionsWidget(TQWidget * parent)
 				"It's an ugly hack - use it only if nothing else works.</center>","options"));
 #endif
 									
-	connect(b2,TQT_SIGNAL(toggled(bool)),b,TQT_SLOT(setEnabled(bool)));
+	connect(b2,TQ_SIGNAL(toggled(bool)),b,TQ_SLOT(setEnabled(bool)));
 
 	b = addBoolSelector(0,1,1,1,__tr2qs_ctx("Notify failed DCC handshakes to the remote end","options"),
 									KviOption_boolNotifyFailedDccHandshakes);
@@ -195,18 +195,18 @@ KviDccSendGeneralOptionsWidget::KviDccSendGeneralOptionsWidget(TQWidget * parent
 
 	KviBoolSelector * b;
 
-	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("On Incoming File","options"));
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,TQt::Horizontal,__tr2qs_ctx("On Incoming File","options"));
 	KviBoolSelector * b2 = addBoolSelector(g,__tr2qs_ctx("Automatically accept","options"),KviOption_boolAutoAcceptDccSend);
 	KviBoolSelector * b3 = addBoolSelector(g,__tr2qs_ctx("Open transfer window as minimized when auto-accepted","options"),KviOption_boolCreateMinimizedDccSendWhenAutoAccepted,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedDccSend));
 	KviBoolSelector * b4 = addBoolSelector(g,__tr2qs_ctx("Automatically resume when auto-accepted","options"),KviOption_boolAutoResumeDccSendWhenAutoAccepted,KVI_OPTION_BOOL(KviOption_boolAutoAcceptDccSend));
 
-	g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Save Location","options"));
+	g = addGroupBox(0,1,0,1,1,TQt::Horizontal,__tr2qs_ctx("Save Location","options"));
 	addDirectorySelector(g,__tr2qs_ctx("Download folder:","options"),KviOption_stringIncomingPath);
 	addBoolSelector(g,__tr2qs_ctx("Sort saved files by nicknames (create subfolders)","options"),KviOption_boolSortReceivedByDccFilesByNicks);
 	addBoolSelector(g,__tr2qs_ctx("Guess save path from media type","options"),KviOption_boolUseIncomingDccMediaTypeSavePath);
 
 
-	g = addGroupBox(0,2,0,2,1,Qt::Horizontal,__tr2qs_ctx("On Download Completion","options"));
+	g = addGroupBox(0,2,0,2,1,TQt::Horizontal,__tr2qs_ctx("On Download Completion","options"));
 	addBoolSelector(g,__tr2qs_ctx("Notify completion in console","options"),KviOption_boolNotifyDccSendSuccessInConsole);
 	addBoolSelector(g,__tr2qs_ctx("Notify completion in notifier","options"),KviOption_boolNotifyDccSendSuccessInNotifier);
 	b = addBoolSelector(g,__tr2qs_ctx("Automatically clear transfer","options"),KviOption_boolAutoCloseDccSendOnSuccess);
@@ -219,8 +219,8 @@ KviDccSendGeneralOptionsWidget::KviDccSendGeneralOptionsWidget(TQWidget * parent
 
 	KviBoolSelector * b1 = addBoolSelector(0,3,0,3,__tr2qs_ctx("Always open transfer window as minimized","options"),KviOption_boolCreateMinimizedDccSend);
 
-	connect(b1,TQT_SIGNAL(toggled(bool)),b3,TQT_SLOT(setNotEnabled(bool)));
-	connect(b2,TQT_SIGNAL(toggled(bool)),b4,TQT_SLOT(setEnabled(bool)));
+	connect(b1,TQ_SIGNAL(toggled(bool)),b3,TQ_SLOT(setNotEnabled(bool)));
+	connect(b2,TQ_SIGNAL(toggled(bool)),b4,TQ_SLOT(setEnabled(bool)));
 
 	addRowSpacer(0,4,0,4);
 }
@@ -235,7 +235,7 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(TQWidget * pare
 {
 	createLayout(4,1);
 
-	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("Bug Compatibility","options"));
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,TQt::Horizontal,__tr2qs_ctx("Bug Compatibility","options"));
 	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Send ACK for byte 0","options"),KviOption_boolSendZeroAckInDccRecv);
 #ifdef COMPILE_INFO_TIPS
 	mergeTip(b,
@@ -259,19 +259,19 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(TQWidget * pare
 #endif //COMPILE_INFO_TIPS
 
 
-	g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("Limits","options"));
+	g = addGroupBox(0,1,0,1,1,TQt::Horizontal,__tr2qs_ctx("Limits","options"));
 
 	KviTalHBox * hb = new KviTalHBox(g);
 	b = addBoolSelector(hb,__tr2qs_ctx("Limit upload bandwidth to","options"),KviOption_boolLimitDccSendSpeed);
 	KviUIntSelector * u = addUIntSelector(hb,"",KviOption_uintMaxDccSendSpeed,0,0xffffff1,1024,KVI_OPTION_BOOL(KviOption_boolLimitDccSendSpeed));
 	u->setSuffix(" " + __tr2qs_ctx("bytes/sec","options"));
-	connect(b,TQT_SIGNAL(toggled(bool)),u,TQT_SLOT(setEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),u,TQ_SLOT(setEnabled(bool)));
 	
 	hb = new KviTalHBox(g);
 	b = addBoolSelector(hb,__tr2qs_ctx("Limit download bandwidth to","options"),KviOption_boolLimitDccRecvSpeed);
 	u = addUIntSelector(hb,"",KviOption_uintMaxDccRecvSpeed,0,0xffffff1,1024,KVI_OPTION_BOOL(KviOption_boolLimitDccRecvSpeed));
 	u->setSuffix(" " + __tr2qs_ctx("bytes/sec","options"));
-	connect(b,TQT_SIGNAL(toggled(bool)),u,TQT_SLOT(setEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),u,TQ_SLOT(setEnabled(bool)));
 
 
 	u = addUIntSelector(g,__tr2qs_ctx("Maximum number of DCC transfers","options"),KviOption_uintMaxDccSendTransfers,0,1000,10);
@@ -280,7 +280,7 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(TQWidget * pare
 					"KVIrc will refuse the requests when this limit is reached.</center>","options"));
 #endif
 
-	g = addGroupBox(0,2,0,2,1,Qt::Horizontal,__tr2qs_ctx("Tweaks","options"));
+	g = addGroupBox(0,2,0,2,1,TQt::Horizontal,__tr2qs_ctx("Tweaks","options"));
 
 	b = addBoolSelector(g,__tr2qs_ctx("Use fast send (send ahead)","options"),KviOption_boolUseFastDccSend);
 #ifdef COMPILE_INFO_TIPS
@@ -302,7 +302,7 @@ KviDccSendAdvancedOptionsWidget::KviDccSendAdvancedOptionsWidget(TQWidget * pare
 #endif // COMPILE_INFO_TIPS
 
 	u = addUIntSelector(hb,"",KviOption_uintDccSendIdleStepInMSec,1,65536,30,KVI_OPTION_BOOL(KviOption_boolDccSendForceIdleStep));
-	connect(b,TQT_SIGNAL(toggled(bool)),u,TQT_SLOT(setEnabled(bool)));
+	connect(b,TQ_SIGNAL(toggled(bool)),u,TQ_SLOT(setEnabled(bool)));
 	u->setSuffix(__tr2qs_ctx(" msec","options"));
 	
 #ifdef COMPILE_INFO_TIPS
@@ -346,13 +346,13 @@ KviDccChatOptionsWidget::KviDccChatOptionsWidget(TQWidget * parent)
 {
 	createLayout(3,1);
 
-	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,Qt::Horizontal,__tr2qs_ctx("On Chat Request","options"));
+	KviTalGroupBox * g = addGroupBox(0,0,0,0,1,TQt::Horizontal,__tr2qs_ctx("On Chat Request","options"));
 	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Automatically accept","options"),KviOption_boolAutoAcceptDccChat);
 	b = addBoolSelector(g,__tr2qs_ctx("Open minimized when auto-accepted","options"),KviOption_boolCreateMinimizedDccChatWhenAutoAccepted,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedDccChat));
 
 	KviBoolSelector * b1 = addBoolSelector(0,1,0,1,__tr2qs_ctx("Always open as minimized","options"),KviOption_boolCreateMinimizedDccChat);
 
-	connect(b1,TQT_SIGNAL(toggled(bool)),b,TQT_SLOT(setNotEnabled(bool)));
+	connect(b1,TQ_SIGNAL(toggled(bool)),b,TQ_SLOT(setNotEnabled(bool)));
 
 	addRowSpacer(0,2,0,2);
 }
@@ -367,11 +367,11 @@ KviDccVoiceOptionsWidget::KviDccVoiceOptionsWidget(TQWidget *p):KviOptionsWidget
 	createLayout(8, 1);
 
 	KviBoolSelector * b1 = addBoolSelector(0,0,0,0,__tr2qs_ctx("Open all minimized","options"),KviOption_boolCreateMinimizedDccVoice);
-	KviTalGroupBox * g = addGroupBox(0,1,0,1,1,Qt::Horizontal,__tr2qs_ctx("On Voice Request","options"));
+	KviTalGroupBox * g = addGroupBox(0,1,0,1,1,TQt::Horizontal,__tr2qs_ctx("On Voice Request","options"));
 	KviBoolSelector * b = addBoolSelector(g,__tr2qs_ctx("Automatically accept","options"),KviOption_boolAutoAcceptDccVoice);
 
 	b = addBoolSelector(g,__tr2qs_ctx("Open minimized when auto-accepted","options"),KviOption_boolCreateMinimizedDccVoiceWhenAutoAccepted,!KVI_OPTION_BOOL(KviOption_boolCreateMinimizedDccVoice));
-	connect(b1,TQT_SIGNAL(toggled(bool)),b,TQT_SLOT(setNotEnabled(bool)));
+	connect(b1,TQ_SIGNAL(toggled(bool)),b,TQ_SLOT(setNotEnabled(bool)));
 
 	addBoolSelector(0,2,0,2,__tr2qs_ctx("Force half-duplex mode on sound device","options"), KviOption_boolDccVoiceForceHalfDuplex);
 	addBoolSelector(0,3,0,3,__tr2qs_ctx("Volume slider controls PCM, not Master","options"), KviOption_boolDccVoiceVolumeSliderControlsPCM);
