@@ -32,7 +32,7 @@
 
 class KviIgnoreOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviIgnoreOptionsWidget(TQWidget * parent);
