@@ -33,7 +33,7 @@
 
 class KviQueryOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviQueryOptionsWidget(TQWidget * parent);
