@@ -42,8 +42,8 @@ KviTextIconEditor::KviTextIconEditor(TQWidget * par,KviTextIcon * icon,KviTextIc
 	m_pIcon = icon;
 	m_pPopup = 0;
 	updateIcon();
-	connect(m_pIconButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(doPopup()));
-	connect(m_pBrowseButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(chooseFromFile()));
+	connect(m_pIconButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(doPopup()));
+	connect(m_pBrowseButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(chooseFromFile()));
 }
 
 
@@ -58,7 +58,7 @@ void KviTextIconEditor::doPopup()
 	{
 		m_pPopup = new KviTalPopupMenu(this);
 		KviIconWidget * iw = new KviIconWidget(m_pPopup);
-		connect(iw,TQT_SIGNAL(selected(int)),this,TQT_SLOT(iconSelected(int)));
+		connect(iw,TQ_SIGNAL(selected(int)),this,TQ_SLOT(iconSelected(int)));
 		m_pPopup->insertItem(iw);
 	}
 	m_pPopup->popup(TQCursor::pos());
@@ -164,15 +164,15 @@ KviTextIconsOptionsWidget::KviTextIconsOptionsWidget(TQWidget * parent)
 
 	m_pAdd = new TQPushButton(__tr2qs_ctx("Add","options"),this);
 	layout()->addWidget(m_pAdd,1,0);
-	connect(m_pAdd,TQT_SIGNAL(clicked()),this,TQT_SLOT(addClicked()));
+	connect(m_pAdd,TQ_SIGNAL(clicked()),this,TQ_SLOT(addClicked()));
 
 	m_pDel = new TQPushButton(__tr2qs_ctx("Delete","options"),this);
 	layout()->addWidget(m_pDel,1,1);
-	connect(m_pDel,TQT_SIGNAL(clicked()),this,TQT_SLOT(delClicked()));
+	connect(m_pDel,TQ_SIGNAL(clicked()),this,TQ_SLOT(delClicked()));
 
 	m_pDel->setEnabled(false);
 
-	connect(m_pTable,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(selectionChanged()));
+	connect(m_pTable,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(selectionChanged()));
 }
 
 KviTextIconsOptionsWidget::~KviTextIconsOptionsWidget()
