@@ -178,7 +178,7 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 	m_pListView->setAllColumnsShowFocus(true);
 
 	m_pListView->setSelectionMode(KviTalListView::Extended);
-	m_pListView->setRootIsDecorated(TRUE);
+	m_pListView->setRootIsDecorated(true);
 
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pListView,__tr2qs("<center>This is the list of registered users. " \
@@ -463,7 +463,7 @@ void KviRegisteredUsersDialog::fillList()
 	{
 		KviRegisteredUsersGroupItem* pCur = new KviRegisteredUsersGroupItem(m_pListView,g);
 		groupItems.insert(g->name(),pCur);
-		pCur->setOpen(TRUE);
+		pCur->setOpen(true);
 	}
 	
 	KviPointerHashTable<TQString,KviRegisteredUser> * d = g_pLocalRegisteredUserDataBase->userDict();
