@@ -120,7 +120,7 @@ static bool reguser_kvs_cmd_edit(KviKvsModuleCommandCall * c)
 				g_pRegisteredUsersDialog->reparent(0,TQPoint(0,0),true);
 			}
 		} else {
-			if(TQT_BASE_OBJECT(g_pRegisteredUsersDialog->parent()) != TQT_BASE_OBJECT(c->window()->frame()->splitter()))
+			if(g_pRegisteredUsersDialog->parent() != c->window()->frame()->splitter())
 			{
 				g_pRegisteredUsersDialog->reparent(c->window()->frame()->splitter(),TQPoint(0,0),true);
 			}
