@@ -73,7 +73,7 @@ KviSharedFileEditDialog::KviSharedFileEditDialog(TQWidget * par,KviSharedFile *
 
 	m_pBrowseButton = new TQPushButton(__tr2qs_ctx("&Browse...","sharedfileswindow"),this);
 	g->addWidget( m_pBrowseButton, 1, 3 );
-	connect(m_pBrowseButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(browse()));
+	connect(m_pBrowseButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(browse()));
 
 	l = new TQLabel(__tr2qs_ctx("User mask:","sharedfileswindow"),this);
 	g->addWidget(l, 2, 0 );
@@ -87,16 +87,16 @@ KviSharedFileEditDialog::KviSharedFileEditDialog(TQWidget * par,KviSharedFile *
 	m_pExpireDateTimeEdit = new TQDateTimeEdit(this);
 	g->addMultiCellWidget(m_pExpireDateTimeEdit, 3, 3, 1, 3 );
 
-	connect(m_pExpireCheckBox,TQT_SIGNAL(toggled(bool)),m_pExpireDateTimeEdit,TQT_SLOT(setEnabled(bool)));
+	connect(m_pExpireCheckBox,TQ_SIGNAL(toggled(bool)),m_pExpireDateTimeEdit,TQ_SLOT(setEnabled(bool)));
 
 	TQPushButton * pb;
 
 	pb = new TQPushButton(__tr2qs_ctx("&OK","sharedfileswindow"),this);
-	connect(pb,TQT_SIGNAL(clicked()),this,TQT_SLOT(okClicked()));
+	connect(pb,TQ_SIGNAL(clicked()),this,TQ_SLOT(okClicked()));
 	pb->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	g->addWidget(pb,5,2);
 	pb = new TQPushButton(__tr2qs_ctx("Cancel","sharedfileswindow"),this);
-	connect(pb,TQT_SIGNAL(clicked()),this,TQT_SLOT(reject()));
+	connect(pb,TQ_SIGNAL(clicked()),this,TQ_SLOT(reject()));
 	pb->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DISCARD)));
 	g->addWidget(pb,5,3);
 
@@ -206,7 +206,7 @@ KviSharedFilesWindow::KviSharedFilesWindow(KviModuleExtensionDescriptor * d,KviF
 : KviWindow(KVI_WINDOW_TYPE_TOOL,lpFrm,"shared files window",0) , KviModuleExtension(d)
 {
 	g_pSharedFilesWindow = this;
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this,"splitter");
+	m_pSplitter = new TQSplitter(TQt::Horizontal,this,"splitter");
 
 	KviTalVBox * vbox = new KviTalVBox(m_pSplitter);
 
@@ -218,20 +218,20 @@ KviSharedFilesWindow::KviSharedFilesWindow(KviModuleExtensionDescriptor * d,KviF
 	m_pListView->addColumn(__tr2qs_ctx("Mask","sharedfileswindow"),200);
 	m_pListView->addColumn(__tr2qs_ctx("Expires","sharedfileswindow"),200);
 	m_pListView->setSelectionMode(KviTalListView::Single);
-	connect(m_pListView,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(enableButtons()));
+	connect(m_pListView,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(enableButtons()));
 
-	connect(g_pSharedFilesManager,TQT_SIGNAL(sharedFilesChanged()),this,TQT_SLOT(fillFileView()));
-	connect(g_pSharedFilesManager,TQT_SIGNAL(sharedFileAdded(KviSharedFile *)),this,TQT_SLOT(sharedFileAdded(KviSharedFile *)));
-	connect(g_pSharedFilesManager,TQT_SIGNAL(sharedFileRemoved(KviSharedFile *)),this,TQT_SLOT(sharedFileRemoved(KviSharedFile *)));
+	connect(g_pSharedFilesManager,TQ_SIGNAL(sharedFilesChanged()),this,TQ_SLOT(fillFileView()));
+	connect(g_pSharedFilesManager,TQ_SIGNAL(sharedFileAdded(KviSharedFile *)),this,TQ_SLOT(sharedFileAdded(KviSharedFile *)));
+	connect(g_pSharedFilesManager,TQ_SIGNAL(sharedFileRemoved(KviSharedFile *)),this,TQ_SLOT(sharedFileRemoved(KviSharedFile *)));
 
 	KviTalHBox * b = new KviTalHBox(vbox);
 
 	m_pAddButton = new TQPushButton(__tr2qs_ctx("&Add...","sharedfileswindow"),b);
-	connect(m_pAddButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(addClicked()));
+	connect(m_pAddButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(addClicked()));
 	m_pRemoveButton = new TQPushButton(__tr2qs_ctx("Re&move","sharedfileswindow"),b);
-	connect(m_pRemoveButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(removeClicked()));
+	connect(m_pRemoveButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(removeClicked()));
 	m_pEditButton = new TQPushButton(__tr2qs_ctx("&Edit","sharedfileswindow"),b);
-	connect(m_pEditButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(editClicked()));
+	connect(m_pEditButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(editClicked()));
 
 	fillFileView();
 }
@@ -380,7 +380,7 @@ void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const TQPoi
 	if(!m_pOpenFilePopup)
 	{
 		m_pOpenFilePopup= new KviTalPopupMenu(this);
-		connect(m_pOpenFilePopup,TQT_SIGNAL(activated(int)),this,TQT_SLOT(openFilePopupActivated(int)));
+		connect(m_pOpenFilePopup,TQ_SIGNAL(activated(int)),this,TQ_SLOT(openFilePopupActivated(int)));
 	}
 
 	m_pContextPopup->clear();
@@ -440,18 +440,18 @@ void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const TQPoi
 
 				m_pOpenFilePopup->insertSeparator();
 
-				id = m_pOpenFilePopup->insertItem(__tr2qs_ctx("Default application","filetransferwindow"),this,TQT_SLOT(openLocalFile()));
+				id = m_pOpenFilePopup->insertItem(__tr2qs_ctx("Default application","filetransferwindow"),this,TQ_SLOT(openLocalFile()));
 				m_pOpenFilePopup->setItemParameter(id,-1);
-				id = m_pOpenFilePopup->insertItem(__tr2qs_ctx("&Other...","filetransferwindow"),this,TQT_SLOT(openLocalFileWith()));
+				id = m_pOpenFilePopup->insertItem(__tr2qs_ctx("&Other...","filetransferwindow"),this,TQ_SLOT(openLocalFileWith()));
 				m_pOpenFilePopup->setItemParameter(id,-1);
 
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open with","filetransferwindow"),m_pOpenFilePopup);
 				m_pLocalFilePopup->insertSeparator();
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open folder","filetransferwindow"),this,TQT_SLOT(openLocalFileFolder()));
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Reach in terminal","filetransferwindow"),this,TQT_SLOT(openLocalFileTerminal()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open folder","filetransferwindow"),this,TQ_SLOT(openLocalFileFolder()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Reach in terminal","filetransferwindow"),this,TQ_SLOT(openLocalFileTerminal()));
 				m_pLocalFilePopup->insertSeparator();
 #endif //COMPILE_TDE_SUPPORT
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Copy path to clipboard","filetransferwindow"),this,TQT_SLOT(copyLocalFileToClipboard()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Copy path to clipboard","filetransferwindow"),this,TQ_SLOT(copyLocalFileToClipboard()));
 
 				m_pContextPopup->insertItem(__tr2qs_ctx("Local file","filetransferwindow"),m_pLocalFilePopup);
 			}
@@ -474,10 +474,10 @@ void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const TQPoi
 		item = (KviSharedFilesItem *)item->nextSibling();
 	}
 
-	id = m_pContextPopup->insertItem(__tr2qs_ctx("Clear terminated","filetransferwindow"),this,TQT_SLOT(clearTerminated()));
+	id = m_pContextPopup->insertItem(__tr2qs_ctx("Clear terminated","filetransferwindow"),this,TQ_SLOT(clearTerminated()));
 	m_pContextPopup->setItemEnabled(id,bHaveTerminated);
 	
-	id = m_pContextPopup->insertItem(__tr2qs_ctx("Clear all","filetransferwindow"),this,TQT_SLOT(clearAll()));
+	id = m_pContextPopup->insertItem(__tr2qs_ctx("Clear all","filetransferwindow"),this,TQ_SLOT(clearAll()));
 	m_pContextPopup->setItemEnabled(id,it);
 
 	m_pContextPopup->popup(pnt);
