@@ -496,7 +496,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 				return false;
 			}
 			ds << iii;
-		} else if(kvi_strEqualCI(TQSTRING_OBJECT_NAME_STRING,szType.ptr()))
+		} else if(kvi_strEqualCI("TQString",szType.ptr()))
 		{
 			TQString ddd = tmp.ptr();
 			ds << ddd;
@@ -543,7 +543,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 				bool bqw;
 				ret >> bqw;
 				c->returnValue()->setInteger(bqw ? 1 : 0);
-			} else if(szRetType == TQSTRING_OBJECT_NAME_STRING)
+			} else if(szRetType == "TQString")
 			{
 				TQString szz;
 				ret >> szz;
@@ -565,7 +565,6 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 				c->returnValue()->setInteger(iii);
 			} else if(szRetType == "QCStringList")
 			{
-#ifndef COMPILE_USE_QT4
 				QCStringList csl;
 				ret >> csl;
 				KviKvsArray * arry = new KviKvsArray();
@@ -576,8 +575,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 					idx++;
 				}
 				c->returnValue()->setArray(arry);
-#endif
-			} else if(szRetType == TQSTRINGLIST_OBJECT_NAME_STRING)
+			} else if(szRetType == "TQStringList")
 			{
 				TQStringList csl;
 				ret >> csl;
