@@ -38,7 +38,7 @@ class KviFrame;
 
 class KviTermWidget : public TQFrame
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	TQ_PROPERTY( int KviProperty_ChildFocusOwner READ dummy )
 public:
