@@ -160,7 +160,7 @@ KviThemeManagementDialog::KviThemeManagementDialog(TQWidget * parent)
 	tb->setIconSet(*(g_pIconManager->getBigIcon(KVI_BIGICON_SAVE)));
 	tb->setUsesBigPixmap(true);
 	TQToolTip::add(tb,__tr2qs_ctx("Save Current Theme...","theme"));
-	connect(tb,TQT_SIGNAL(clicked()),this,TQT_SLOT(saveCurrentTheme()));
+	connect(tb,TQ_SIGNAL(clicked()),this,TQ_SLOT(saveCurrentTheme()));
 
 	sep = new TQFrame(hb);
 	sep->setFrameStyle(TQFrame::VLine | TQFrame::Sunken);
@@ -170,13 +170,13 @@ KviThemeManagementDialog::KviThemeManagementDialog(TQWidget * parent)
 	m_pPackThemeButton->setIconSet(*(g_pIconManager->getBigIcon(KVI_BIGICON_PACK)));
 	m_pPackThemeButton->setUsesBigPixmap(true);
 	TQToolTip::add(m_pPackThemeButton,__tr2qs_ctx("Export Selected Themes to a Distributable Package","theme"));
-	connect(m_pPackThemeButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(packTheme()));
+	connect(m_pPackThemeButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(packTheme()));
 
 	m_pDeleteThemeButton = new KviStyledToolButton(hb);
 	m_pDeleteThemeButton->setIconSet(*(g_pIconManager->getBigIcon(KVI_BIGICON_REMOVE)));
 	m_pDeleteThemeButton->setUsesBigPixmap(true);
 	TQToolTip::add(m_pDeleteThemeButton,__tr2qs_ctx("Delete Selected Themes","theme"));
-	connect(m_pDeleteThemeButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(deleteTheme()));
+	connect(m_pDeleteThemeButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(deleteTheme()));
 
 	sep = new TQFrame(hb);
 	sep->setFrameStyle(TQFrame::VLine | TQFrame::Sunken);
@@ -186,13 +186,13 @@ KviThemeManagementDialog::KviThemeManagementDialog(TQWidget * parent)
 	tb->setIconSet(*(g_pIconManager->getBigIcon(KVI_BIGICON_OPEN)));
 	tb->setUsesBigPixmap(true);
 	TQToolTip::add(tb,__tr2qs_ctx("Install Theme Package From Disk","theme"));
-	connect(tb,TQT_SIGNAL(clicked()),this,TQT_SLOT(installFromFile()));
+	connect(tb,TQ_SIGNAL(clicked()),this,TQ_SLOT(installFromFile()));
 
 	tb = new KviStyledToolButton(hb);
 	tb->setIconSet(*(g_pIconManager->getBigIcon(KVI_BIGICON_WWW)));
 	tb->setUsesBigPixmap(true);
 	TQToolTip::add(tb,__tr2qs_ctx("Get More Themes...","theme"));
-	connect(tb,TQT_SIGNAL(clicked()),this,TQT_SLOT(getMoreThemes()));
+	connect(tb,TQ_SIGNAL(clicked()),this,TQ_SLOT(getMoreThemes()));
 
 	TQWidget *w= new TQWidget(hb);
 	w->setSizePolicy(TQSizePolicy::Expanding,TQSizePolicy::Minimum);
@@ -201,17 +201,17 @@ KviThemeManagementDialog::KviThemeManagementDialog(TQWidget * parent)
 	m_pListBox->setMinimumHeight(400);
 	m_pListBox->setMinimumWidth(400);
 	m_pListBox->setSelectionMode(KviTalListBox::Extended);
-	connect(m_pListBox,TQT_SIGNAL(doubleClicked(KviTalListBoxItem *)),this,TQT_SLOT(applyTheme(KviTalListBoxItem *)));
-	connect(m_pListBox,TQT_SIGNAL(contextMenuRequested(KviTalListBoxItem *,const TQPoint &)),
-		this,TQT_SLOT(contextMenuRequested(KviTalListBoxItem *,const TQPoint &)));
-	connect(m_pListBox,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(enableDisableButtons()));
+	connect(m_pListBox,TQ_SIGNAL(doubleClicked(KviTalListBoxItem *)),this,TQ_SLOT(applyTheme(KviTalListBoxItem *)));
+	connect(m_pListBox,TQ_SIGNAL(contextMenuRequested(KviTalListBoxItem *,const TQPoint &)),
+		this,TQ_SLOT(contextMenuRequested(KviTalListBoxItem *,const TQPoint &)));
+	connect(m_pListBox,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(enableDisableButtons()));
 	g->addMultiCellWidget(m_pListBox,1,1,0,1);
 
 	KviDynamicToolTip * tip = new KviDynamicToolTip(m_pListBox); 
-	connect(tip,TQT_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQT_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &))); 
+	connect(tip,TQ_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQ_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &))); 
 
 	TQPushButton * b = new TQPushButton(__tr2qs("Close"),this);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(closeClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(closeClicked()));
 	g->addWidget(b,2,1);
 
 	g->setRowStretch(1,0);
@@ -280,8 +280,8 @@ void KviThemeManagementDialog::contextMenuRequested(KviTalListBoxItem * it,const
 	{
 		m_pListBox->setCurrentItem(it);
 		m_pContextPopup->clear();
-		m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MINUS)),__tr2qs_ctx("&Remove Theme","theme"),this,TQT_SLOT(deleteTheme()));
-		m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)),__tr2qs_ctx("&Apply Theme","theme"),this,TQT_SLOT(applyCurrentTheme()));
+		m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MINUS)),__tr2qs_ctx("&Remove Theme","theme"),this,TQ_SLOT(deleteTheme()));
+		m_pContextPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)),__tr2qs_ctx("&Apply Theme","theme"),this,TQ_SLOT(applyCurrentTheme()));
 		m_pContextPopup->popup(pos);
 	}
 }
